%% MisMeasurePBS2b: process adjusted data
% obtain parameters for the adjusted data from MisMeasurePBS2a
%
% uses code from 'io_table_17Sec_1997_2015revised'
% 
% A.Hornstein, 11/5/2021
% revised 12/10/2021: mostly just commentary
% -------------------------------------------------------------------------
inputlocFAT='..\data_bea_fat\DataProcessed\';
inputlocIO ='..\data_io_cap\DataProcessed\';
inputlocAdj='DataProcessed\';
outputloc  ='DataProcessed\';
adjname ='Inter2Invest';
% work with N sector aggregation
N=17;

% adjusted capital flows: commodity by industry contributions to industry investment
fname=[inputlocAdj 'CapFlow_16Sec_ComByInd_1997-2015_' adjname];
load(fname,'tt','omegaAdj');
ttCF=tt;
% adjusted industry investment by type: E, S, & IPP
fname=[inputlocAdj 'BEA_FA_Industry_Invest_17sec_' adjname];
load(fname,'tt','xxI2','xxE2','xxS2','xname2');
ttFA=tt;
% residential structures 
fname=[inputlocFAT 'BEA_FA_RESI_Invest'];
load(fname,'tt','xxR','xnameR');
xxR=xxR(:,1);
xnameR=xnameR{1};
ttR=tt;

% tt=(1997:2015);
tt=(2015:2015);
nt=length(tt);
for i = 1:nt
    % use data from Use Tables and FATs for year 'date'
    date=tt(i);
    %% load adjusted Commmodity by Industry Use and Make Table for 17 sectors
    fname=[inputlocAdj 'IOUse_ComByInd17Sec_1997-2015_' adjname '.xlsx'];
    useT=readtable(fname,'Sheet',num2str(date),'Range','A1', ...
        'ReadVariableNames',true,'ReadRowNames',true);
    use=useT.Variables;
    useRname=useT.Properties.RowNames;
    useCname=useT.Properties.VariableNames;
    secName=useCname(1:N);
    fname=[inputlocIO 'IOMake_ComByInd17Sec_1997-2015.xlsx'];
    makeT=readtable(fname,'Sheet',num2str(date),'Range','A1', ...
        'ReadVariableNames',true,'ReadRowNames',true);
    make=makeT.Variables;
    %% Transformation from Commodity-By-Industry to Industry-By-Industry --
    % components of make-use matrices as defined in BEA (2012) CH.12
    % use components
    U =use(1:N+2,1:N);         % intermediate goods part, incl scraps and noncomps
    e =use(1:N+2,N+4:N+23);    % final use, inclusive scrap and noncomparables
    qU=use(1:N+2,end);         % commodity gross output from use
    gU=use(end,1:N);           % industry gross output from use
    va=use(N+2+[(4:6) 9],1:N); % value added and components
    % make components
    g=make(1:N,N+3);        % industry gross output from Make, g=qI
    V=make(1:N,1:N+2);      % industry comm production, incl srcaps and con comp's
    qM=make(N+1,1:N+2);     % commodity gross output from make
    % -- Direct Requirement Table: Share of Inputs, Columns Sum to 1 -- %
    B=U*diag(1./gU);        
    % -- Industry Market Share Table: Industry Share of Total Commodity Production, Columns Sum to 1 -- %
    D=V*diag(1./qM);    
    % industry-by-industry use and requirement matrix
    Uii=D*U;
    Bii=D*B;
    % industry-by-final demand requirement matrix
    ei =D*e;
    eis=ei*diag(1./sum(ei,1));    
    
    % industry-by-industry use table    
    useII=zeros(N+4+1,N+20+1);
    useII(1:N,1:N)=Uii;     % intermediate inputs
    useII(1:N,N+(1:20))=ei; % final use
    useII(1:N,N+21)=gU;     % industry gross output
    useII(N+(1:4),1:N)=va;  % value added
    useII(N+5,1:N)=gU;      % industry gross output
    % check useII: rows (columns) sum to final row (column)
    rdumR=100*(sum(useII([(1:N) N+4],1:N),1)./useII(N+5,1:N) -1);
    rdumC=100*(sum(useII(1:N,1:N+20),2)./useII(1:N,N+21) -1);
    
    useIIRname=useRname(1:N+5);
    useIIRname(N+(1:4))=useRname(N+2+[(4:6) 9]);
    useIIRname(N+5)=useRname(length(useRname));
    useIICname=useCname(1:N+20+1);
    useIICname(N+(1:20))=useCname(N+3+(1:20));
    useIICname(N+21)=useRname(length(useRname));
    useIIT=array2table(useII,'VariableNames',useIICname,'RowNames',useIIRname);
    fname=[outputloc 'IOUse_IndByInd17Sec_1997-2015_' adjname '.xlsx'];
    writetable(useIIT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
        
    %% Calibration Parameters -- %
    gma  =(va(end,:)./gU)';    
    phi  =Bii*diag(1./sum(Bii,1));
    theta=eis(:,1);
    vaShr=(va(end,:)./sum(va(end,:),2))';
    alpha=( va(3,:)./sum(va([1 3],:),1) )';
    % industry contributions to investment types    
    omgS =eis(:,2);
    omgE =eis(:,3);
    omgI =eis(:,4);
    omgR =eis(:,5);
    % industry contributions to industry investment
    j=(ttFA==date);
    xxSEI =[xxS2(j,:); xxE2(j,:); xxI2(j,:) ]; 
    omgSEI=[omgS,omgE,omgI];  
    omg=zeros(N,N);
    for j=1:3
        omg=omg+kron(omgSEI(:,j),xxSEI(j,:));
    end
    % now add resi inv to investment in housing sector (N-1)
    j=(ttR==date); 
    omg(:,N-1)=omg(:,N-1)+xxR(j)*omgR;
    omg=omg*diag(1./sum(omg,1));
    % commodity by industry contributions to investment, already adjusted
    omega=omegaAdj{ttCF==date};    
   
    filename = [outputloc 'IO_IndByInd17Sec_' adjname '_' num2str(date)];
    save(filename,'phi','gma','theta','vaShr','alpha','omgE','omgS','omgI','omgR','omg','omega');   
    
    % table representation of share parameters
    % phi
    phiT=array2table(phi,'VariableNames',secName,'RowNames',secName);
    fname=[outputloc 'IOphi_IndByInd17Sec_1997-2015_' adjname '.xlsx'];
    writetable(phiT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    % omg
    omgT=array2table(omg,'VariableNames',secName,'RowNames',secName);
    fname=[outputloc 'IOomg_IndByInd17Sec_1997-2015_' adjname '.xlsx'];
    writetable(omgT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    % par
    par =[alpha,gma,theta,omgE,omgI,omgS,omgR,vaShr];
    parName={'alpha','gamma','theta','Equip','IPP','NonRes S','Res S','VA/GDP'};
    parT=array2table(par,'VariableNames',parName,'RowNames',secName);
    fname=[outputloc 'IOpar_IndByInd17Sec_1997-2015_' adjname '.xlsx'];
    writetable(parT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    
    % Note that we don't have a government sector and that some of the
    % investment requirements are negative (comes from scrap?)   
    % phi: eliminate government, and rescale phi again
    phi=phi(1:N-1,1:N-1);
    phi=phi*diag(1./sum(phi,1));
    phiT=array2table(phi,'VariableNames',secName(1:N-1),'RowNames',secName(1:N-1));
    fname=[outputloc 'IOphi_IndByInd17Sec_1997-2015_' adjname '_final.xlsx'];
    writetable(phiT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    % omg: eliminate gov'mnt, impose non-negativity and rescale omg again
    omg=omg(1:N-1,1:N-1);
    omg=max(omg,zeros(N-1,N-1));
    omg=omg*diag(1./sum(omg,1));
    omgT=array2table(omg,'VariableNames',secName(1:N-1),'RowNames',secName(1:N-1));
    fname=[outputloc 'IOomg_IndByInd17Sec_1997-2015_' adjname '_final.xlsx'];
    writetable(omgT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    % par: eliminate gov'mnt, impose non-negativity and rescale omg of par again
    npar=size(par,2);
    par=max(par(1:N-1,:),zeros(N-1,npar));
    par(:,3:end)=par(:,3:end)*diag(1./sum(par(:,3:end),1));    
    parT=array2table(par,'VariableNames',parName,'RowNames',secName(1:N-1));
    fname=[outputloc 'IOpar_IndByInd17Sec_1997-2015_' adjname '_final.xlsx'];
    writetable(parT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    j=1;
    alpha=par(:,j);j=j+1;
    gma  =par(:,j);j=j+1;
    theta=par(:,j);j=j+1;
    omgE =par(:,j);j=j+1;
    omgI =par(:,j);j=j+1;    
    omgS =par(:,j);j=j+1;
    omgR =par(:,j);j=j+1;
    vaShr=par(:,j);
    omega=omegaAdj{i};
    filename = [outputloc 'IO_IndByInd17Sec_' adjname '_' num2str(date) '_final'];
    save(filename,'phi','gma','theta','vaShr','alpha','omgE','omgS','omgI','omgR','omg','omega');

end