% BEA_FA_Data_Import
% (1) Import nominal investment data from the BEA Fixed Asset tables 
%     By type (equipment, structures, and IPP) for the 63 private sectors
%        BEA FA Tables 3.7E, 3.7S, 3.7I by type
%        BEA FA Tables 3.7ESI sum of types
%     By type for overall government and government components, Billions $s
%        BEA FA Tables 7.5 by type and federal, S & L
%     Residential structures by legal organization.
%        BEA FA Tables 5.7 by legal org
%     All data Nominal in billions of $s.
% (2) Aggregate private investment into 16 2-digit sectors 
% (2.1) add residential investment to the housing sector
% (2.2) add overall government investment to the 16 private sectors
% (2.3) split out 2 main IPP investment producing PBS sectors: 
%         Computer Systems Design (NAICS 5415)
%         Misc prof, scientific, and technical services (NAICS 5412OP)
% (3) Save investment data into
%     BEA_FA_Industry_Invest_63sec: detailed private industries, x63
%     BEA_FA_Industry_Invest_64sec: detailed private indust's + overall gov
%         x64=[ x63 xG]
%     BEA_FA_Industry_Invest_16sec: aggregated private industries, excl resi struc, x16
%         x16 with x16(12)=PBS and x16(16)=Res Housing
%     BEA_FA_Industry_Invest_17sec: agg private ind's, excl resi, + gov
%         x17=[ x16 xG]
%     BEA_FA_Industry_Invest_18sec: agg private ind's (IT PBS split out), excl resi struc + gov
%         x18=[ x16mod xPBSipp xG] x16mod(12)=x16(12)-xPBSipp
%     BEA_FA_Industry_Invest_17Rsec: agg private ind's, incl resi, + gov
%         x17R=x17 and x17R(16)=x16(16)+xR
%     BEA_FA_Industry_Invest_18Rsec: agg private ind's (IT PBS split out), incl resi + gov
%         x18R=x18 and x18R(16)=x18(16)+xR
%     Each output files contains separate investment arrays for E, S, and
%     IPP by industry.
%
% A.Hornstein, 11/4/2021
% revised 12/8/2021
% -------------------------------------------------------------------------
% SetPath
% real values: real=nominal in 2009
tNorm=2009;
% sample: use only data from t0 to t1
t0=1947;
t1=3000;

%% Nominal investment data from BEA FA tables 
% - by industry and type, 1947-2020, billions of $s
% - for government, 1901-2020, billions of $s
% -------------------------------------------------------------------------
inputloc='DataRaw\';
outputloc='DataProcessed\';
% private industry investment by type
fnameE=[inputloc 'BEA_FA37E_Industry_Invest_Eqmnt.xls'];
fnameS=[inputloc 'BEA_FA37S_Industry_Invest_Structures.xls'];
fnameI=[inputloc 'BEA_FA37I_Industry_Invest_IPP.xls'];
fnameESI=[inputloc 'BEA_FA37ESI_Industry_Invest.xls'];
OutputFileNameESI =[outputloc 'BEA_FA_Industry_Invest'];
% residential structures
fnameR=[inputloc 'BEA_FA57_ResidentialStructures_Invest.xls'];
OutputFileNameR=[outputloc 'BEA_FA_RESI_Invest'];
% government investment, F,S&L
fnameG=[inputloc 'BEA_FA75_Govmnt_Invest.xls'];
OutputFileNameG=[outputloc 'BEA_FA_Govmnt_Invest'];
% -------------------------------------------------------------------------
%% import investment types for private industries, 63 sectors
% number of industries
nI=63;
% equipment investment
[data,txt]=xlsread(fnameE,'Sheet0');
xxE=data';
tt=str2double(txt(6,3:end))';
nt=length(tt);
xname=txt(8:85,2);
% structures investment
[data,~]=xlsread(fnameS,'Sheet0');
xxS=data';
% IPP investment
[data,~]=xlsread(fnameI,'Sheet0');
xxI=data';
save([OutputFileNameESI '_63sec'],'tt','xxE','xxS','xxI','xname');

%% define 2 digit industries with 16 private sectors
nI2=16;
xname2=cell(nI2,1);i=1;
xname2{i}='Agri, Forestry et al';i=i+1;
xname2{i}='Mining';i=i+1;
xname2{i}='Utilities';i=i+1;
xname2{i}='Construction';i=i+1;
xname2{i}='Durable Goods';i=i+1;
xname2{i}='Nondurable Goods';i=i+1;
xname2{i}='Wholesale Trade';i=i+1;
xname2{i}='Retail Trade';i=i+1;
xname2{i}='Transp and Warehousing';i=i+1;
xname2{i}='Information';i=i+1;
xname2{i}='FIRE ex Housing';i=i+1;
xname2{i}='Prof and Bus Services';i=i+1;
xname2{i}='Edu, Health Care, and Social Ass';i=i+1;
xname2{i}='Arts, Entertainment, etc';i=i+1;
xname2{i}='Other Services, excl Government';i=i+1;
xname2{i}='Housing Services';
idx2={2; 5; 9; 10; 12; 24; 33; 34; 35; 44; [49 57]; [58 62 63]; 66:67; [72 75]; 78; 55};

nI2=size(idx2,1);
xxE2=NaN(nt,nI2);
xxS2=xxE2;xxI2=xxE2;
for i=1:nI2
    jj=cell2mat(idx2(i));
    xxE2(:,i)=sum(xxE(:,jj),2);
    xxS2(:,i)=sum(xxS(:,jj),2);
    xxI2(:,i)=sum(xxI(:,jj),2);
end
xx2=xxS2+xxE2+xxI2;

save([OutputFileNameESI '_16sec'],'tt','xxE2','xxS2','xxI2','xname2');

% investment type shares for industries, percent
xxS2s=100*xxS2./xx2;
xxE2s=100*xxE2./xx2;
xxI2s=100*xxI2./xx2;

% figure;
% for i=1:nI2
%     subplot(4,4,i);hold on
%     plot(tt,xxS2s(:,i),'r-');
%     plot(tt,xxE2s(:,i),'b-');
%     plot(tt,xxI2s(:,i),'g-');
%     title(xname2{i});
%     xlim([tt(1) tt(end)]);
% end
% legend({'Struct','Eqmnt','IPP'});
% pause

%% import government investment
[~,xnameG]=xlsread(fnameG,'Sheet0','B8:B98');
[data,~]  =xlsread(fnameG,'Sheet0','C8:DR98');
xxG=data';
nt=size(xxG,1);
tt=1901+(0:nt-1)';
% adjust sample size
ii=(t0<=tt);
tt=tt(ii);
xxG=xxG(ii,:);
% extract E, S, and IPP investment
xxGE=xxG(:,2);
xxGS=xxG(:,3);
xxGI=xxG(:,18);
xxGT=xxGE+xxGS+xxGI;

save(OutputFileNameG,'tt','xxG','xnameG');

% figure;hold on
% plot(tt,xxGS./xxGT,'r-');
% plot(tt,xxGE./xxGT,'b-');
% plot(tt,xxGI./xxGT,'g-');
% xlim([tt(1) tt(end)]);
% title('Government: Shares of Investment');
% legend({'Struct','Eqmnt','IPP'});
% pause

%% add government to private industries, so now have 17 and 64 sectors
xxE=[xxE xxGE ];
xxS=[xxS xxGS ];
xxI=[xxI xxGI ];
nx=length(xname);
xname{nx+1}='Government';
save([OutputFileNameESI '_64sec'],'tt','xxE','xxS','xxI','xname');

xxE2=[xxE2 xxGE ];
xxS2=[xxS2 xxGS ];
xxI2=[xxI2 xxGI ];
nI2=nI2+1;
xname2{nI2}='Government';
save([OutputFileNameESI '_17sec'],'tt','xxE2','xxS2','xxI2','xname2');

%% separate out PBS investment in Computer Systems Design (5415) and Misc Scientific Svcs (5412OP)
%  lines 60&61 in spreadsheet
rE=sum(xxE(:,[60 61]),2);
rS=sum(xxS(:,[60 61]),2);
rI=sum(xxI(:,[60 61]),2);
xxE2(:,12)=xxE2(:,12)-rE;
xxS2(:,12)=xxS2(:,12)-rS;
xxI2(:,12)=xxI2(:,12)-rI;
xxE2=[xxE2(:,1:nI2-1) rE xxGE ];
xxS2=[xxS2(:,1:nI2-1) rS xxGS ];
xxI2=[xxI2(:,1:nI2-1) rI xxGI ];
xname2{12}='PBS, ex IPP';
xname2{nI2}='PBS, IPP';
xname2{nI2+1}='Government';
save([OutputFileNameESI '_18sec'],'tt','xname','xxE2','xxS2','xxI2','xname2');

%% import Residential Structures investment and add to housing sector
[~,xnameR]=xlsread(fnameR,'Sheet0','B8:B21');
[data,~]  =xlsread(fnameR,'Sheet0','C8:DR21');
xxR=data';
nt=size(xxR,1);
tt=1901+(0:nt-1)';
% adjust sample size
ii=(t0<=tt);
tt=tt(ii);
xxR=xxR(ii,:);
save(OutputFileNameR,'tt','xxR','xnameR');

% add resi inv to housing sector for 18 sector decomposition
nI2=size(xxS2,2);
xxS2(:,nI2-2)=xxS2(:,nI2-2)+xxR(:,1);
save([OutputFileNameESI '_18Rsec'],'tt','xxE2','xxS2','xxI2','xname2');

% add resi inv to housing sector for 17 sector decomposition
load([OutputFileNameESI '_17sec'],'tt','xxE2','xxS2','xxI2','xname2');
nI2=size(xxS2,2);
xxS2(:,nI2-1)=xxS2(:,nI2-1)+xxR(:,1);
save([OutputFileNameESI '_17Rsec'],'tt','xxE2','xxS2','xxI2','xname2');

