% BEAdata_15sector_Aggregation
% (1) Import the disaggregated data sets for (1) 1947-1963. (2) 1963-2016,
% and (3) 1987-2018 from the BEAs IILPA 
% (2) Calculate GO, VA, K, N, and M aggregates (nominal and real) for the
% 15 sector aggregates and the corresponding TFP growth rates (VA and GO)
% using the mapping defined in 'Agg15SectorFun'
% (3) Save results in KLEMSbea15_XXXX_X
% Processed data include nominal and real values for gross output (y,yq),
% value added (v,vq), intermediate inputs (m,mq), labor (n,nq), capital
% (k,kq), hours (hrs), and TFP growth rates for gross output (dzy) and
% value added (dzv).  
% Real = nominal in 2012.
% Difference to 16 sector aggregation: FIRE includes 'Financial Services'
% and 'Housing Services' 
% A.Hornstein, 7/10/2019
% revised 11/10/2020: use 1987-2018 BEA spreadsheet with 2012 base year
% revised 12/7/2020: use experimental IILPA for 1947-1963 and 1963-2016 and
% official IILPA for 1987-2018
% revised 1/11/2021: separate aggregation for experimental and official
% IILPA data
% -------------------------------------------------------------------------
fileloc='DataProcessed\';

% -------------------------------------------------------------------------
%% 1947-1963 SIC data with 44 sectors
smpl=1;
% real values: real=nominal in 1963
tNorm=1963;
% Input data
fName ='KLEMSbea_1947_1963_SIC';
InputFileName=[fileloc fName '.mat'];
% Output data: 1/2-digit aggregation to 15 sectors
fName='KLEMSbea15_1947_1963_SIC';
OutputFileName=[fileloc fName '.mat'];

load(InputFileName,'y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');
% 15 sector aggregation
[y,v,k,n,m,yq,vq,kq,nq,mq,hrs,SecName]=Agg15SectorFun(y,v,k,n,m,yq,vq,kq,nq,mq,hrs,tt,tNorm,smpl);
% TFP for aggregated sectors
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);
save(OutputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs','tt');

% -------------------------------------------------------------------------
%% 1963-2016 NAICS data with 63 sectors
smpl=2;
% real values: real=nominal in 2012
tNorm=2012;
% Input data: 
fName ='KLEMSbea_1963_2016_NAICS';
InputFileName=[fileloc fName '.mat'];
% Output data: 1/2-digit aggregation to 15 sectors
fName='KLEMSbea15_1963_2016_NAICS';
OutputFileName=[fileloc fName '.mat'];

load(InputFileName,'y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');

% 15 sector aggregation
[y,v,k,n,m,yq,vq,kq,nq,mq,hrs,SecName]=Agg15SectorFun(y,v,k,n,m,yq,vq,kq,nq,mq,hrs,tt,tNorm,smpl);
% TFP for aggregated sectors
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);
save(OutputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs','tt');

% -------------------------------------------------------------------------
%% 1987-2018 NAICS data with 63 sectors
smpl=2;
% real values: real=nominal in 2012
tNorm=2012;
% Input data: 
fName ='KLEMSbea_1987_2018_NAICS';
InputFileName=[fileloc fName '.mat'];
% Output data: 1/2-digit aggregation to 15 sectors
fName='KLEMSbea15_1987_2018_NAICS';
OutputFileName=[fileloc fName '.mat'];

load(InputFileName,'y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');

% 15 sector aggregation
[y,v,k,n,m,yq,vq,kq,nq,mq,hrs,SecName]=Agg15SectorFun(y,v,k,n,m,yq,vq,kq,nq,mq,hrs,tt,tNorm,smpl);
% TFP for aggregated sectors
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);
save(OutputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs','tt');



