% BEAdata_16sector_Aggregation
% (1) Import the disaggregated data sets for (1) 1947-1963, and for (2)
% 1963-2018 (spliced in 1987) from the BEAs IILPA 
% (2) Import the 1947-2018 dataseries for RE ex Housing and Housing and
% replace the RE series with RE ex Housing and add the Housing series 
% in the last column 
% (3) Calculate GO, VA, K, N, and M aggregates (nominal and real) for the
% 16 sector aggregates and the corresponding TFP growth rates (VA and GO)
% using the mapping defined in 'Agg16SectorFun'
%
% Processed data include nominal and real values for gross output (y,yq),
% value added (v,vq), intermediate inputs (m,mq), labor (n,nq), capital
% (k,kq), hours (hrs), and TFP growth rates for gross output (dzy) and
% value added (dzv).  
% Real = nominal in 2012.
% Difference to 15 sector aggregation: FIRE is split into 'Financial
% Services' and 'Housing Services'
% A.Hornstein, 12/7/2020
% revised 1/11/2021: updated description
% -------------------------------------------------------------------------
fileloc='DataProcessed\';
% -------------------------------------------------------------------------
%% Real Estate separated out as RE ex Housing and Housing
fName1 ='KLEMSbea_RE_Housing_1947_2018';
fname1=[fileloc fName1 '.mat'];
load(fname1,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');
t1=tt;
y1=y;
v1=v;
k1=k;
n1=n;
m1=m;
yq1=yq;
vq1=vq;
kq1=kq;
nq1=nq;
mq1=mq;
hrs1=hrs;
sec1=SecName;

% -------------------------------------------------------------------------
%% 1963-2018 NAICS data with 63 sectors
smpl=2;
% real values: real=nominal in 2012
tNorm=2012;
% Input data: 
fName ='KLEMSbea_1963_1987_2018_NAICS';
InputFileName=[fileloc fName '.mat'];
% Output data: 1/2-digit aggregation to 16 sectors
fName='KLEMSbea16_1963_1987_2018_NAICS';
OutputFileName=[fileloc fName '.mat'];

load(InputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');

% no need to re-normalize RE, since real=nominal in 2012

% replace RE with RE ex Housing and attach Housing as last colum
idx1=(t1>=tt(1));
iRE=45;
y=[ y, y1(idx1,2)]; y(:,iRE)=y1(idx1,1);
v=[ v, v1(idx1,2)]; v(:,iRE)=v1(idx1,1);
k=[ k, k1(idx1,2)]; k(:,iRE)=k1(idx1,1);
n=[ n, n1(idx1,2)]; n(:,iRE)=n1(idx1,1);
m=[ m, m1(idx1,2)]; m(:,iRE)=m1(idx1,1);
yq=[ yq, yq1(idx1,2)]; yq(:,iRE)=yq1(idx1,1);
vq=[ vq, vq1(idx1,2)]; vq(:,iRE)=vq1(idx1,1);
kq=[ kq, kq1(idx1,2)]; kq(:,iRE)=kq1(idx1,1);
nq=[ nq, nq1(idx1,2)]; nq(:,iRE)=nq1(idx1,1);
mq=[ mq, mq1(idx1,2)]; mq(:,iRE)=mq1(idx1,1);
hrs=[ hrs, hrs1(idx1,2)]; hrs(:,iRE)=hrs1(idx1,1);

% 16 sector aggregation
[y,v,k,n,m,yq,vq,kq,nq,mq,hrs,SecName]=Agg16SectorFun(y,v,k,n,m,yq,vq,kq,nq,mq,hrs,tt,tNorm,smpl);
% TFP for aggregated sectors
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);
save(OutputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs','tt');

% -------------------------------------------------------------------------
%% 1947-1963 SIC data with 44 sectors
smpl=1;
% real values: real=nominal in 1963
tNorm=1963;
% Input data
fName ='KLEMSbea_1947_1963_SIC';
InputFileName=[fileloc fName '.mat'];
% Output data: 1/2-digit aggregation to 15 sectors
fName='KLEMSbea16_1947_1963_SIC';
OutputFileName=[fileloc fName '.mat'];
load(InputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','hrs','tt');

% re-normalize RE
i0=find(t1==tNorm);
yq1=yq1*diag(y1(i0,:)./yq1(i0,:));
vq1=vq1*diag(v1(i0,:)./vq1(i0,:));
kq1=kq1*diag(k1(i0,:)./kq1(i0,:));
nq1=nq1*diag(n1(i0,:)./nq1(i0,:));
mq1=mq1*diag(m1(i0,:)./mq1(i0,:));

% replace RE with RE ex Housing and attach Housing as last colum
iRE=32;
idx1=(t1<=tt(end));
y=[ y, y1(idx1,2)]; y(:,iRE)=y1(idx1,1);
v=[ v, v1(idx1,2)]; v(:,iRE)=v1(idx1,1);
k=[ k, k1(idx1,2)]; k(:,iRE)=k1(idx1,1);
n=[ n, n1(idx1,2)]; n(:,iRE)=n1(idx1,1);
m=[ m, m1(idx1,2)]; m(:,iRE)=m1(idx1,1);
yq=[ yq, yq1(idx1,2)]; yq(:,iRE)=yq1(idx1,1);
vq=[ vq, vq1(idx1,2)]; vq(:,iRE)=vq1(idx1,1);
kq=[ kq, kq1(idx1,2)]; kq(:,iRE)=kq1(idx1,1);
nq=[ nq, nq1(idx1,2)]; nq(:,iRE)=nq1(idx1,1);
mq=[ mq, mq1(idx1,2)]; mq(:,iRE)=mq1(idx1,1);
hrs=[ hrs, hrs1(idx1,2)]; hrs(:,iRE)=hrs1(idx1,1);

% 16 sector aggregation
[y,v,k,n,m,yq,vq,kq,nq,mq,hrs,SecName]=Agg16SectorFun(y,v,k,n,m,yq,vq,kq,nq,mq,hrs,tt,tNorm,smpl);
% TFP for aggregated sectors
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);
save(OutputFileName,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs','tt');

