% BEAdataImport_1947_1963_SIC
% (1) Import data for 44 sectors from the EXPERIMENTAL BEA/BLS Integrated
%     Production Accounts for the years 1947-1963
% (2) The BEA data for capital and labor are disaggregated by types. We
%     construct input aggregates as Divisia indices. 
% (3) Calculate TFP growth (VA and GO) for each sector
% Processed data include nominal and real values for gross output (y,yq),
% value added (v,vq), intermediate inputs (m,mq), labor (n,nq), capital
% (k,kq), and TFP growth rates for gross output (dzy) and value added (dzv). 
% Nominal in millions of $s.
% Real = nominal in 1963.
% A.Hornstein, 12/4/2020
% -------------------------------------------------------------------------
% real values: real=nominal in 1963
tNorm=1963;
% -------------------------------------------------------------------------
% KLEMS data from BEA production account, 
% 1947-1963 SIC 44 sectors with quantities 2009=1 (?)
% -------------------------------------------------------------------------
inputloc='DataRaw\';
outputloc='DataProcessed\';
fnameInput='BEA_tables_detail_1947_2016.xlsx';
fnameInput=[inputloc fnameInput];
fnameOutput=[outputloc 'KLEMSbea_1947_1963_SIC'];
% number of industries
nI=44;
% sample period
t0=1947;
t1=1963;
nt=t1-t0+1;
% types of capital and labor
nk=5;
ktype={'it.','soft.','rd.','art.','oth.'};
nn=2;
ntype={'col.','n.'};

[~, txt]=xlsread(fnameInput,'notes');
SecName=cell(nI,1);
for i=1:nI
    SecName{i}=txt{10+i,5};
end
SecIdx=[(1:28) 2936 3740 4144 (45:46) 4749 50 5152 53 5456 5758 (59:63) ];
[data,txt]=xlsread(fnameInput,'1947-1963','A1:V750');
txt=txt(2,4:22);
tt=data(1:nt,1);
ii=data(:,2);
data=data(:,4:end);

% rearrange data
y=NaN(nt,nI);k=y;m=y;n=y;
yq=y;kq=y;mq=y;nq=y;hrs=y;

itNorm=find(tt==tNorm);
for i=1:nI    
    xx=data(ii==SecIdx(i),:);
    % gross output
    j=find(strcmp('go.',txt));
    y(:,i)=xx(:,j);
    j=find(strcmp('qgo.',txt));
    yq(:,i)=xx(:,j)*y(itNorm,i)/xx(itNorm,j);
    % intermediate input
    j=find(strcmp('ii.',txt));
    m(:,i)=xx(:,j);
    j=find(strcmp('qii.',txt));
    mq(:,i)=xx(:,j)*m(itNorm,i)/xx(itNorm,j);
    % capital input
    kkV=NaN(nt,nk);kkQ=kkV;
    for ik=1:nk
        j=find(strcmp(['vk' ktype{ik} ],txt));
        kkV(:,ik)=xx(:,j);
        j=find(strcmp(['qk' ktype{ik} ],txt));
        kkQ(:,ik)=xx(:,j)*kkV(itNorm,ik)/xx(itNorm,j);
    end
    [k(:,i),kq(:,i)]=DivisiaQ(kkV,kkQ,tt,tNorm);
    % labor input
    nnV=NaN(nt,nn);nnQ=nnV;
    for in=1:nn
        j=find(strcmp(['vl' ntype{in} ],txt));
        nnV(:,in)=xx(:,j);
        j=find(strcmp(['ql' ntype{in} ],txt));
        nnQ(:,in)=xx(:,j)*nnV(itNorm,in)/xx(itNorm,j);
    end
    [n(:,i),nq(:,i)]=DivisiaQ(nnV,nnQ,tt,tNorm);
    j=find(strcmp('hrs.',txt));
    hrs(:,i)=xx(:,j);
end
% VA
[v,vq]=VAfun(y,m,yq,mq,tt,tNorm);
% TFP for gross output and VA 
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);

% save BEA data
save(fnameOutput,'SecName','SecIdx','tt','y','v','k','n','m',...
    'yq','vq','kq','nq','mq','dzy','dzv','hrs');
