% BEAdataImport_1987_2018_NAICS
% (1) Import data for 63 sectors from the OFFICIAL BEA/BLS Integrated
%     Production Accounts for the years 1987-2018
% (2) The BEA data for intermediate inputs, capital, and labor are
%     disaggregated by types. We construct input aggregates as Divisia
%     indices. 
% (3) Calculate TFP growth (VA and GO) for each sector
% (4) Hours are a quantity index, 2012=100. Rescale hours using total hours
%     worked from the experimental IILPA for 1963-2016.
% Processed data include nominal and real values for gross output (y,yq),
% value added (v,vq), intermediate inputs (m,mq), labor (n,nq), capital
% (k,kq), and TFP growth rates for gross output (dzy) and value added (dzv). 
% Nominal in millions of $s.
% Real = nominal in 2012.
% A.Hornstein, 7/9/2019
% revised 11/10/2020: use updated 1987-2018 BEA spreadsheet, redefined
% 'VA_Quantity' in spreadsheet to 'Value Added_Quantity'
% revised 1/11/2021: moved to Data_Replication_1947_2018
% -------------------------------------------------------------------------
% SetPath
% real values: real=nominal in 2012
tNorm=2012;
% -------------------------------------------------------------------------
% KLEMS data from BEA production account, 1987-2018
% quantities 2012=100
% -------------------------------------------------------------------------
inputloc='DataRaw\';
outputloc='DataProcessed\';
nameBEA='BEA';
fnameBEA='BEA-BLS industry-level production account_1987-2018.xlsx';
fnameBEA=[inputloc fnameBEA];
OutputFileNameBEA=[outputloc 'KLEMSbea_1987_2018_NAICS'];
% number of industries
nI=63;
% types of capital, labor, and intermediate inputs
nk=5;
ktype={'Art','R&D','IT','Other','Software'};
nn=2;
ntype={'Labor_Col','Labor_NoCol'};
nm=3;
mtype={'Energy','Materials','Services'};
% -------------------------------------------------------------------------
% import gross output, nominal and real
vName='Gross Output';
[tt,y,SecName]=ImportBEA(fnameBEA,vName);
[~,yq]=ImportBEA(fnameBEA,[vName '_Quantity']);
% constant 2012$'s
yq=(yq/100)*diag(y(tt==tNorm,:));

% -------------------------------------------------------------------------
% import value added, nominal and real
vName='Value Added';
[tt,v]=ImportBEA(fnameBEA,vName);
[~,vq]=ImportBEA(fnameBEA,[vName '_Quantity']);
% constant 2012$'s
vq=(vq/100)*diag(v(tt==tNorm,:));

% -------------------------------------------------------------------------
% import intermediate input types, nominal and real, and construct
% aggregate intermediate input, nominal and real in 2012$'s
mmC=cell(nm,1);
mmQ=cell(nm,1);
for i=1:nm
    [tt,mmC{i}]=ImportBEA(fnameBEA,[mtype{i} ' Compensation']);
    [~,mmQ{i}]=ImportBEA(fnameBEA,[mtype{i} '_Quantity']);
end
nt=length(tt);
m =zeros(nt,nI);
mq=zeros(nt,nI);
for i=1:nI
    MC=NaN(nt,nm);
    MQ=NaN(nt,nm);
    for j=1:nm
        MC(:,j)=mmC{j}(:,i);
        MQ(:,j)=mmQ{j}(:,i);
    end
    [m(:,i),mq(:,i)]=DivisiaQ(MC,MQ,tt,tNorm);
end

% -------------------------------------------------------------------------
% import labor types, nominal and real, and construct aggregate labor
% input, nominal and real in 2012$'s
nnC=cell(nn,1);
nnQ=cell(nn,1);
for i=1:nn
    [tt,nnC{i}]=ImportBEA(fnameBEA,[ntype{i} ' Compensation']);
    [~,nnQ{i}]=ImportBEA(fnameBEA,[ntype{i} '_Quantity']);
end
nt=length(tt);
n =zeros(nt,nI);
nq=zeros(nt,nI);
for i=1:nI
    MC=NaN(nt,nn);
    MQ=NaN(nt,nn);
    for j=1:nn
        MC(:,j)=nnC{j}(:,i);
        MQ(:,j)=nnQ{j}(:,i);
    end
    [n(:,i),nq(:,i)]=DivisiaQ(MC,MQ,tt,tNorm);
end
% import hours, quantity index, 2012=100
[tt,hrs]=ImportBEA(fnameBEA,'Labor Hours_Quantity');

% -------------------------------------------------------------------------
% inport capital service types, nominal and real, and construct aggregate
% capital input, nominal and real in 2012$'s
kkC=cell(nk,1);
kkQ=cell(nk,1);
for i=1:nk
    [tt,kkC{i}]=ImportBEA(fnameBEA,['Capital_' ktype{i} ' Compensation']);
    [~,kkQ{i}]=ImportBEA(fnameBEA,['Capital_' ktype{i} '_Quantity']);
end
nt=length(tt);
k =zeros(nt,nI);
kq=zeros(nt,nI);
for i=1:nI
    KC=NaN(nt,nk);
    KQ=NaN(nt,nk);
    for j=1:nk
        KC(:,j)=kkC{j}(:,i);
        KQ(:,j)=kkQ{j}(:,i);
    end
    [k(:,i),kq(:,i)]=DivisiaQ(KC,KQ,tt,tNorm);
end

% -------------------------------------------------------------------------
% TFP for gross output and VA 
[dzy,dzv]=TFPfun(yq,vq,kq,nq,mq,k,n,m);

% save BEA data
save(OutputFileNameBEA,'SecName','tt','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','hrs');


