% Replication files for 'Aggregate Implications of Changing Sectoral Trends' (January 18, 2020)
% Andrew Foerster, Andreas Hornstein, Pierre-Daniel Sarte, Mark Watson
% 
% Programs:  All programs use MATLAB
% 
% Programs to produce the KLEMS data
% Unprocessed data files are in the 'DataRaw' subdirectory, these include 
% (1) the official IILPAs from 1987-2018 (NAICS)
% (2) the detailed experimental and IILPAs from 1947-1963 (SIC) and from 1963-2016 (NAICS)
% Processed MATLAB data files are in the 'DataProcessed' subdirectory
% 
% Run the following programs in sequence

BEAdata_Import_1947_1963_SIC
% (1) Import data for 44 sectors from the EXPERIMENTAL BEA/BLS Integrated 
%     Production Accounts for the years 1947-1963
% (2) The BEA data for capital and labor are disaggregated by types. We
%     construct input aggregates as Divisia indices. 
% (3) Calculate TFP growth (VA and GO) for each sector

BEAdata_Import_1963_2016_NAICS
% (1) Import data for 63 sectors from the EXPERIMENTAL BEA/BLS Integrated
%     Production Accounts for the years 1963-2016
% (2) The BEA data for capital and labor are disaggregated by types. We
%     construct input aggregates as Divisia indices. 
% (3) Calculate TFP growth (VA and GO) for each sector

BEAdata_Import_1987_2018_NAICS
% (1) Import data for 63 sectors from the OFFICIAL BEA/BLS Integrated
%     Production Accounts for the years 1987-2018
% (2) The BEA data for intermediate inputs, capital, and labor are
%     disaggregated by types. We construct input aggregates as Divisia
%     indices. 
% (3) Calculate TFP growth (VA and GO) for each sector

BEAdata_Hours_1987_2018_NAICS
% Sectoral hours in the OFFICIAL IILPAs are a quantity index, 2012=100.
% Rescale hours using total hours worked from the EXPERIMENTAL IILPA for
% 1963-2016. 

BEAdata_Splice_1963_2016_with_1987_2018
% Splice the detailed 63 industries of (1) the experimental NAICS IILPA from 
% 1963-2016 with (2) the official IILPA from 1987-2018. 
% Splice the series in 1987, ie, rely on the official IILPA as much as
% possible.

BEAdata_15sector_Aggregation
% (1) Import the disaggregated data sets for (1) 1947-1963, (2) 1963-2016,
%     and (3) 1987-2018 from the BEAs IILPA 
% (2) Calculate GO, VA, K, N, and M aggregates (nominal and real) for the
%    15 sector aggregates and the corresponding TFP growth rates (VA and GO)
%    using the mapping defined in 'Agg15SectorFun'

BEAdata_15Sector_Splice_1963_2016_with_1987_2018
% Splice the 15 sector aggregates of (1) the experimental NAICS IILPA from 
% 1963-2016 with (2) the official IILPA from 1987-2018. 
% Splice the series in 1987, ie, rely on the official IILPA as much as
% possible.

BEAdata_15Sector_Splice_1947_1963_with_1963_1987_2018
% Splice the 15 sector aggregate of (1) the experimental NAICS IILPA from
% 1947-1963 with (2) the combined experimental and official NAICS IILPA
% from 1963-2018, merged in 1987.  

BEAdata_Split_Housing_from_RealEstate
% (1) Import 'Real Estate' (RE) from the IILPA 
% (2) Split the 'Real Estate' (RE) sector into 'Residential Housing' (REH)
%     and 'Other RE' (REO) based on NIPA data for the Housing Sector, Tables 7.4 
%     (a) Split GO, intermediate inputs, and GVA using nominal and real GO,
%         M, and GVA from RE and REH
%     (b) Split labor according to labor compensation shares of REH and REO
%     (c) Split capital according to capital income shares of REH and REO

BEAdata_16sector_Aggregation
% (1) Import the disaggregated data sets for (1) 1947-1963, and for (2)
%     1963-2018 (spliced in 1987) from the BEAs IILPA 
% (2) Import the 1947-2018 dataseries for RE ex Housing and Housing and
%     replace the RE series with RE ex Housing and add the Housing series 
%     in the last column 
% (3) Calculate GO, VA, K, N, and M aggregates (nominal and real) for the
%     16 sector aggregates and the corresponding TFP growth rates (VA and GO)
%     using the mapping defined in 'Agg16SectorFun'

BEAdata_16Sector_Splice_1947_1963_with_1963_1987_2018
% Splice the 16 sector aggregates of (1) the experimental NAICS IILPA from
% 1947-1963 with (2) the combined experimental and official NAICS IILPA
% from 1963-2018, merged in 1987.  