function [v,vq]=VAfun(y,m,yq,mq,t,t0)
% VAfun nominal and real VA, v&vq, for gross output, y&yq, and intermediate
% inputs, m&mq, with real=nominal VA at t0
% A.Hornstein, 7/10/2019
% -------------------------------------------------------------------------
[nt,nI]=size(y);
v=y;msy=y;
dvq=zeros(nt,nI);
for i=1:nI 
    % value added, nominal
    v(:,i)=y(:,i)-m(:,i);
    % input cost shares, relative to gross output
    msy(:,i)=m(:,i)./y(:,i);
    % average input cost shares, adjacent periods
    msyi=0.5*(msy(1:end-1,i)+msy(2:end,i));
    % quantity growth rates
    dyqi=diff(log(yq(:,i)));
    dmqi=diff(log(mq(:,i)));
    % real value added growth rate
    dvq(2:end,i)=(dyqi-msyi.*dmqi)./(1-msyi);
end
% Normalization: real = nominal at t0
it0=(t==t0);
% real value added level, normalized
vq=exp(cumsum(dvq));
vq=vq*diag(v(it0,:)./vq(it0,:));

end
