% Table A5: intermediate input and IPP contributions from PBS 
% A.Hornstein, 2/22/2022
% -------------------------------------------------------------------------

% -- Setup -- %
clear;
close all;
clc;

% --- Data path --- %
% PC path
inputloc  ='DataProcessed\';
outputloc ='..\tables\';

date=2015;

fname=[inputloc 'IOUse_ComByInd18Sec_1997-2015.xlsx'];
data=readtable(fname,'Sheet',num2str(date),'Range','b2:at31');

% commodity location
iPBSm  =12; % PBS, ex IPP
iPBSipp=17; % PBS, IPP
% intermediate
iM=23;      
jM=21;   
% total IPP
iIPP=30;
jIPP=25;

data=table2array(data);

xx=NaN(3,2);
% goods produced by PBS-IPP
xx(1,:)=data(iPBSipp,[jM, jIPP]);
xx(2,:)=data(iPBSm,[jM, jIPP]);
xx(3,1)=data(iM,jM);
xx(3,2)=data(iIPP,jIPP);
xx=round(xx/10^3);

rownames={'PBS - IPP','PBS - non IPP','Total'};
varnames={'Intermediates','IPP'};
xxT=array2table(xx,'VariableNames',varnames,'RowNames',rownames);

fname=[outputloc 'TableA5.xlsx'];
writetable(xxT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)

%% print table in TEX format
fmt=cell(10,1);

fmt{1}='\\begin{table}[ht] \n';
fmt{2}='\\centering \n';
fmt{3}='\\caption{Contributions from Professional and Business Services} \n';
fmt{4}='\\begin{tabular}{l|cc} \n';
fmt{5}='\\hline\\hline \n';
fmt{6}='  & Intermediates & IPP \\\\ \n';
fmt{7}='\\hline \n';
fmt{8}=' %s   & %5i & %5i \\\\ \n';
fmt{9}='\\hline\\hline \n';
fmt{10}='\\end{tabular} \n';


fname=[ outputloc 'TableA5.tex'];
fid=fopen(fname,'w');
for i=1:7
    fprintf(fid,fmt{i});
end
for i=1:3
    fprintf(fid,fmt{8},rownames{i},xx(i,:));
end
for i=9:10
    fprintf(fid,fmt{i});
end
fclose(fid);
