% io_table_16Sec_1997_2015.m
% 
% Takes the 1997-2015 BEA Input-Output Make and Use tables with 71 Ind's
% and 71 Commodities and combines industry and commodity definitions to
% match the 15-sector aggregation of KLEMS industries (excl government).
% 
% This script does NOT split FIRE, but includes a government sector
% 
% We use the After-Redefinitions IO matrices
% 
% A. Hornstein, 12/16/2019. Based on io_table_19 by Andrew T. Foerster
% revised 11/1/2021: add final use requirements for major investment
% components
% -------------------------------------------------------------------------
% -- Setup -- %
clear;
close all;
clc;
% --- Data path --- %
% PC path
inputlocIO ='DataRaw\';
inputlocFAT='..\data_bea_fat\DataProcessed\';
outputloc='DataProcessed\';

% -- Industry Codes and Labels -- %
usefile =[inputlocIO 'IOUse_After_Redefinitions_PRO_1997-2015_Summary.xlsx'];
makefile=[inputlocIO 'IOMake_After_Redefinitions_1997-2015_Summary.xlsx'];
[~, ~, indname] = xlsread(usefile,'1997','C6:BX6');
[~, ~, indcode] = xlsread(usefile,'1997','C7:BX7');

% Aggregation of industries/commodities to sectors
N = 16;
agg=cell(N,1);
% 1. Agriculture 
agg{1}=(1:2);
% 2. Mining
agg{2}=(3:5);
% 3. Utilities
agg{3}=6;
% 4. Construction
agg{4}=7;
% 5. Durable Goods
agg{5}=(8:18);
% 6. Nondurable Goods
agg{6}=(19:26);
% 7. Wholesale Trade
agg{7}=27;
% 8. Retail Trade
agg{8}=(28:31);
% 9. Transportation and Warehousing
agg{9}=(32:39);
% 10. Information
agg{10}=(40:43);
% 11. FIRE
agg{11}=(44:50);
% 12. Prof and Business Services
agg{12}=(51:56);
% 13. Education and Health
agg{13}=(57:61);
% 14. Arts, Entertainment, and Food Serv
agg{14}=(62:65);
% 15. Other Services
agg{15}=66;
% 16. Government
agg{16}=(67:71);

% Aggregate Use Table
% use table: column aggregation
aggUC=cell(N+7,1);
aggUC(1:N)=agg;
% 18. Total final uses
aggUC{N+1}=97;
% 19. Total commodity output
aggUC{N+2}=98;
% 20. PCE
aggUC{N+3}=75;
% 21. Investment, Non-res struc
aggUC{N+4}=76;
% 22. Investment, Equipment 
aggUC{N+5}=77;
% 23. Investment, IPP 
aggUC{N+6}=78;
% 24. Investment, Resi struc
aggUC{N+7}=79;

% use table: row aggregation
aggUR=cell(N+3,1);
aggUR(1:N)=agg;
% 18. Scrap and RoW Noncomp's
aggUR{N+1}=(72:73);
% 19. Value Added
aggUR{N+2}=82;
% 20. Total Industry output 
aggUR{N+3}=83;


% Aggregate Make Table
% Make table: column aggregation
aggMC=cell(N+2,1);
aggMC(1:N)=agg;
% 18. Scrap and RoW
aggMC{N+1}=(72:73);
% 19. Total industry output
aggMC{N+2,1}=74;
% Make table: row aggregation
aggMR=cell(N+1,1);
aggMR(1:N)=agg;
% 18. Total commodity output
aggMR{N+1}=72;

aggName=cell(N+1,1);i=1;
aggName{i}='Agriculture et al';i=i+1;
aggName{i}='Mining';i=i+1;
aggName{i}='Utilities';i=i+1;
aggName{i}='Construction';i=i+1;
aggName{i}='Durable Goods';i=i+1;
aggName{i}='Nondurable Goods';i=i+1;
aggName{i}='Wholesale Trade';i=i+1;
aggName{i}='Retail Trade';i=i+1;
aggName{i}='Transp and Warehousing';i=i+1;
aggName{i}='Information';i=i+1;
aggName{i}='FIRE';i=i+1;
aggName{i}='Prof and Bus Svcs';i=i+1;
aggName{i}='Edu and Health Care';i=i+1;
aggName{i}='Arts and Enter';i=i+1;
aggName{i}='Other Services, excl Gov';i=i+1;
aggName{i}='Government';i=i+1;
aggName{i}='Value Added';

ColName=cell(N,1);i=1;
ColName{i}='Agri';i=i+1;
ColName{i}='Mining';i=i+1;
ColName{i}='Utilities';i=i+1;
ColName{i}='Construction';i=i+1;
ColName{i}='DURGoods';i=i+1;
ColName{i}='NDRGoods';i=i+1;
ColName{i}='Wholesale';i=i+1;
ColName{i}='Retail';i=i+1;
ColName{i}='Transportation';i=i+1;
ColName{i}='Information';i=i+1;
ColName{i}='FIRE';i=i+1;
ColName{i}='ProfSvcs';i=i+1;
ColName{i}='EduHealth';i=i+1;
ColName{i}='Arts';i=i+1;
ColName{i}='OtherSvcs';i=i+1;
ColName{i}='Government';

% -- Dates and Sector Number -- %
% tt=(1997:2015);
tt=(2015:2015);
nt=length(tt);
fval=NaN(nt,1);xflag=fval;fcon=fval;
for i = 1:nt
    date=tt(i);

    % -- Import Use Table -- %
    [~, ~, rawuse]  = xlsread(usefile,num2str(date),'C8:CV90');
    rawuse(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),rawuse)) = {''};
    rawuse(cellfun(@(x) ~isnumeric(x) && ~islogical(x),rawuse)) = {0}; % Replace non-numeric cells
    rawuse=cell2mat(rawuse);

    % -- Import Make Table -- %
    [~, ~, rawmake] = xlsread(makefile,num2str(date),'C8:BX79');   
    rawmake(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),rawmake)) = {''};
    rawmake(cellfun(@(x) ~isnumeric(x) && ~islogical(x),rawmake)) = {0}; % Replace non-numeric cells
    rawmake=cell2mat(rawmake);

    % -- Aggregate from Raw Definitions to New Industry Definitions -- %
    use=aggXX(rawuse,aggUR,aggUC);
    make=aggXX(rawmake,aggMR,aggMC);
    
    % components of make-use matrices as defined in BEA (2012) CH.12
    % use components
    pce=use(1:N,N+3);       % PCE
    invS=use(1:N,N+4);      % investment, non-residential structures
    invE=use(1:N,N+5);      % investment, equipment
    invI=use(1:N,N+6);      % investment, IPP
    invR=use(1:N,N+7);      % investment, residential structures
    q=use(1:N,N+2);         % commodity gross output
    fd=use(1:N,N+1);        % commodity final demand
    U=use(1:N,1:N);         % intermediate goods part, excl scraps and noncomps
    Us=use(N+1,1:N);        % scrap and noncomps, intermediate
    es=use(N+1,N+1);        % scrap and noncomps, final
    qs=use(N+1,N+2);        % scrap and noncomps, total
    va=use(N+2,1:N);        % value added
    % make components
    g=make(1:N,N+2);        % industry gross output
    h=make(1:N,N+1);        % industry scrap production
    V=make(1:N,1:N);        % industry comm production, excl srcaps


    % --------------------------------------------------------------------
    % direct requirement, com by industry    
    % --------------------------------------------------------------------
    Bci=use(1:N+2,1:N)/diag(use(end,1:N));
    % remove scrap and rescale
    sc=1-Bci(N+1,:);
    Bci(N+1,:)=0;
    Bci=Bci*diag(1./sc);
    %res=1-sum(Bci,1);
    Bci=Bci([(1:N) N+2],:);
    
    % -- Export to Excel -- %
    fname=[outputloc 'IO Matrices ComByInd17Sec.xlsx'];
    BciT=array2table(Bci,'VariableNames',ColName,'RowNames',aggName);
    writetable(BciT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)
    % -- Calibration Parameters -- %
    gma  =Bci(N+1,:);
    phi  =Bci(1:N,:)*diag(1./(1-gma));
    theta=pce/sum(pce);
    omgE =invE/sum(invE);
    omgS =invS/sum(invS);
    omgI =invI/sum(invI);
    omgR =invR/sum(invR);
    fdShr=fd/sum(fd);
    vaShr=va'/sum(va,2);
    filename = [outputloc 'IO_ComByInd16Sec_' num2str(date)];
    save(filename,'phi','gma','theta','fdShr','vaShr','omgE','omgS','omgI','omgR');

    % --------------------------------------------------------------------
    % direct requirement, comm by comm: uses commodity-technology approach
    % subject to non-negativity and adding up restrictions
    % --------------------------------------------------------------------
    Bcc=use(1:N+2,1:N)/V';
    % rows don't sum to one
    sc=sum(Bcc,1);
    Bcc=Bcc*diag(1./sc);
    %res=1-sum(Bcc,1);
      
    % remove scrap and rescale
    sc=1-Bcc(N+1,:);
    Bcc(N+1,:)=0;
    Bcc=Bcc*diag(1./sc);
    %res=1-sum(Bcc,1);
    Bcc=Bcc([(1:N) N+2],:);

    % -- Export to Excel -- %
    fname=[ outputloc 'IO Matrices ComByCom16Sec.xlsx'];
    BccT=array2table(Bcc,'VariableNames',ColName,'RowNames',aggName);
    writetable(BccT,fname,'Sheet',num2str(date),'Range','A1','WriteRowNames',true)

    % -- Calibration Parameters -- %
    gma  =Bcc(N+1,:);
    phi  =Bcc(1:N,:)*diag(1./(1-gma));
    theta=pce/sum(pce);
    fdShr=fd/sum(fd);
    vaShr=va'/sum(va,2);
    filename = [outputloc 'IO_ComByCom16Sec' num2str(date)];
    save(filename,'phi','gma','theta','fdShr','vaShr');

end
% -------------------------------------------------------------------------
% Functions used in script
% -------------------------------------------------------------------------
function XX=aggXX(XX,aggR,aggC)
% aggXX aggregate use or make table XX

% Sum of rows: Aggregate detailed commodity use for new industry/commodity
% definitions
N=length(aggR);
XX1=NaN(N,size(XX,2));
for i=1:N
    XX1(i,:)=sum(XX(aggR{i},:),1);
end

% Sum of columns: Aggregate detailed commodity use across new
% industry/commodity definitions 
N=length(aggC);
XX=NaN(size(XX1,1),N);
for i=1:N
    XX(:,i)=sum(XX1(:,aggC{i}),2);
end
end



