% CapitalImportExportAppendixFigure
% (1) Trade in capital goods: Import price indices and values for Imports
%     and Exports of Capital goods from the NIA Foreign Transactions Tables 4.2
% (2) Domestic investment: Import data on nominal equipment investment
%     spending from NIA Savings and Investment Table 5.3.5, Private fixed 
%     investment by type
% (3) Figure for Appendix: Capital Goods excluding MVs
%     (a) Share of imports in domestic investment
%     (b) Terms of trade: relative price of exports and imports
%
% A.Hornstein, 11/12/2021
% -------------------------------------------------------------------------
addpath('\\rb.win.frb.org\E1\Accounts\G-I\e1anh01\My Documents\MyDocs\Programs\Matlab');

InputPathName='DataRaw\';
figdir='..\figures\';

%% Capital goods, Import and Exports, nominal and price index
% NIA Foreign Transactions Tables 4.2
% 1 Capital Goods, ex Auto
% 2 Civilian Aircraft
% 3 Computers
% 4 Other Capital goods, ex Auto
% 5 Automotive

fnameIN='Import Export Data v3';
wksheet='Exports and Imports';
[data,txt]=xlsread([InputPathName fnameIN '.xlsx'],wksheet);
nG=5;
ttXM=str2num(cell2mat(txt(3:end,1)));
txt=txt(2,2:end);
% pX: exports, price indices, 2021=100
j=0;
pX=data(:,j+(1:nG));
pXname=txt(j+(1:nG));
% pM: imports, price indices, 2021=100
j=j+nG;
pM=data(:,j+(1:nG));
pMname=txt(j+(1:nG));
% X: exports, nominal, Billions of $s 
j=j+nG;
X=data(:,j+(1:nG));
Xname=txt(j+(1:nG));
% M: imports, nominal, Billions of $s 
j=j+nG;
M=data(:,j+(1:nG));
Mname=txt(j+(1:nG));
% Names of imported and exported capital goods
Gname={
    'Capital Goods, ex Auto', ...
    'Civilian Aircraft', ...
    'Computers', ...
    'Other Capital goods, ex Auto', ...
    'Automotive'};

%% Domestic Investment: Equipment and IT processing 
% NIA Private Nonresidential Investment, Billions of $s from the NIA Table 5.3.5
% 1 Equipment
% 2 - IT
% 3 -- Computers and peripherals
% 4 -- Other
% 5 - Industrial Equipment
% 6 - Transportation equipment
% 7 -- Aircraft (from Table 5.5.5)
% 8 -- Autos (from Table 5.5.5)
% 9 - Other equipment
% 10 IPP
% 11 - Software
% 12 - R&D
% 13 - Entertainment
% worksheet with Equipment and Software investment
fnameIN ='Import Export Data v3';
wksheet='Investment';
[data,txt]=xlsread([InputPathName fnameIN '.xlsx'],wksheet);
ttInv=str2num(cell2mat(txt(3:end,1)));
Iname=txt(2,2:end);
Inv=data;
InameS={'Eqmnt','IT','IT, Comp','IT, other','Ind E','Transp E','TraE, Aircraft', ...
    'TraE, Autos','E, other','IPP','IPP, soft','IPP, R&D','IPP, E'};
% common sample with Trade data
smpl=(ttInv>=ttXM(1));
Inv=Inv(smpl,:);
ttInv=ttInv(smpl);
nt=length(ttInv);

%% Calculate terms of trade and import shares

% terms of trade
tot=pX./pM;

% Import as a share of domestic investment
M2Inv=NaN(nt,5);
i=0;
% capital goods ex auto
i=i+1;
M2Inv(:,i)=M(:,1)./(Inv(:,1)-Inv(:,8));
% Civilian aircraft
i=i+1;
M2Inv(:,i)=M(:,2)./Inv(:,7);
% computers and peripherals
i=i+1;
M2Inv(:,i)=M(:,3)./Inv(:,3);
% other capital goods ex auto
i=i+1;
M2Inv(:,i)=M(:,4)./Inv(:,9);
% automotive
i=i+1;
M2Inv(:,i)=M(:,5)./Inv(:,8);

%% plot ToT and import shares for all capital goods components   

% plot the terms of trade=pX/pM
fig = figure;
lsty={'r-','r--','r-.','r:','b-'};
hold on;
tt=ttXM;
for i = 1:nG-1
    str = char(pXname{i});
    plot(tt,pX(:,i)./pM(:,i),lsty{i},'LineWidth',2);
end
hold off;
xlim([tt(1) tt(end)]);
legend(Gname(1:nG-1))
title('Terms of Trade');
orient landscape;
% print(fig, [figdir, 'Figure_ToT_4CapitalGoods'], '-dpdf','-bestfit');
% close(gcf);

% plot the import shares of capital goods
fig = figure;
lsty={'r-','r--','r-.','r:','b-'};
hold on;
for i = 1:nG-1
    str = char(pXname{i});
    plot(tt,M2Inv(:,i),lsty{i},'LineWidth',2);
end
hold off;
xlim([tt(1) tt(end)]);
legend(Gname(1:nG-1))
title('Import Shares');
orient landscape;
% print(fig, [figdir, 'Figure_ImpShares_4CapitalGoods'], '-dpdf','-bestfit');
% close(gcf);

%% capital goods, excl auto: plot the terms of trade and the import share
fig=figure;clf
yyaxis left
plot(ttXM,pX(:,1)./pM(:,1),'b-','LineWidth',2);
yyaxis right
plot(ttXM,M2Inv(:,1),'r--','LineWidth',2);
% title(sprintf('Capital Goods, excl Automobiles, %4i-%4i',[ttXM(1) ttXM(end)]));
xlim([ttXM(1) ttXM(end)]);
legend({'Terms of Trade','Import Share'},'Location','NorthWest');
grid on
orient landscape;
print(fig, [figdir, 'FigureA2_TermsOfTrade'], '-dpdf','-bestfit');
close(gcf);

%% calculate avg change of ToT and DUR TFP at annual rate for common sample
fid=1;
smpl=(ttXM<=2018);
tt=ttXM(smpl);
nt=length(tt);
fprintf(fid,'Avg Annual Rate of Change, %4i-%4i: %4.1f percent\n',tt([1,nt]),100*mean(diff(log(tot(smpl,1)))));

% import our TFP growth rates calculated from BEAs KLEMS data 
fileloc='..\data_bea_klems\DataProcessed\';
fname='KLEMSbea16_1947_1963_1987_2018';
load([fileloc fname],'tt','dzv','SecName');
ttKLEMS=tt;
smpl=(ttXM(1)<=ttKLEMS);
tt=tt(smpl);
i=5;
fprintf(fid,'Avg Annual Rate of Change, %s, %4i-%4i: %4.1f percent\n',SecName{i},tt([1,nt]),100*mean(dzv(smpl,1)));




