% Table A6: Alternative price indices for Computer System Design and
% Miscellaneous Services from KLEMS 63 sector data and BEA price data on
% software and R&D 
% A.Hornstein, 2/22/2022
% -------------------------------------------------------------------------

% -- Setup -- %
clear;
close all;
clc;

outputloc='..\tables\';

t0=1963;
t1=2018;
% --- Data path --- %
% KLEMS Data
inputloc='..\data_bea_klems\DataProcessed\';
fname ='KLEMSbea_1963_1987_2018_NAICS.mat';
load([inputloc fname]);
% IPP producing industries in PBS
% 48 computer system design
% 49 Misc services
idx=[48 49];
p1=y(:,idx)./yq(:,idx);
tt1=tt(2:end);
dp1=100*diff(log(p1));

% BEA price data for software and R&D
inputloc='DataRaw\';
fname ='IPP_NIA_prices';
data=readtable([inputloc fname],'Sheet','price','range','a5');
% Columns are
% 1 year
% 2 IPP
%   Software
% 3  Total
% 4  Prepackaged
% 5  Custom
% 6  Own Account
%   R&D
% 7 Total
% 8 Business
% 9 Mft
% 10 Non-Mft
% 11 Scientific R&D
% 12 Computer systems
data=table2array(data);
tt=data(:,1);
p2=data(:,[3 4 5 7]);
smpl=(t0<=tt)&(tt<=t1);
tt2=tt(smpl);
p2=p2(smpl,:);
dp2=100*diff(log(p2));
tt2=tt2(2:end);

% times series for Table A6
tt=tt1;
yy=NaN(length(tt1),8);
yname=cell(1,8);
i=0;
% computer system design
i=i+1;
yname{i}='C Sys Design: KLEMS';
yy(:,i)=dp1(:,1);
i=i+1;
yname{i}='Total';
yy(:,i)=dp2(:,1);
i=i+1;
yname{i}='Software, Pre-packaged';
yy(:,i)=dp2(:,2);
i=i+1;
yname{i}='Custom';
yy(:,i)=dp2(:,3);
i=i+1;
yname{i}='C Sys Design: Modified';
yy(:,i)=(2*dp2(:,2)+dp2(:,3))/3;
% Miscellaneous Svcs
i=i+1;
yname{i}='Misc Svcs: KLEMS';
yy(:,i)=dp1(:,2);
i=i+1;
yname{i}='R&D';
yy(:,i)=dp2(:,4);
i=i+1;
yname{i}='Misc Svcs: Modified';
yy(:,i)=dp2(:,4)-2;

% sample averages
ss=[1964 1985; 1986 2000; 2001 2018];
xx=NaN(3,8);
for i=1:3
    ssi=(ss(i,1)<=tt)&(tt<=ss(i,2));
    xx(i,:)=mean(yy(ssi,:));
end
% 1964-1985: use overall software for modified software becuase no
% separate data for pre-packaged and custom
xx(1,5)=xx(1,2);
rownames={'1964-1985','1986-2000','2001-2018'};
xxT=array2table(xx,'RowNames',rownames,'VariableNames',yname);

fname=[outputloc 'TableA6.xlsx'];
writetable(xxT,fname,'Range','A1','WriteRowNames',true)

%% print table in TEX format
fmt=cell(10,1);
fmt{1}='\\begin{tabular}{l|ccccc|ccc} \n';
fmt{2}='\\hline\\hline \n';
fmt{3}='&\\multicolumn{5}{c|}{Computer System Design} & \\multicolumn{3}{c}{Miscellaneous Services} \\\\ \n';
fmt{4}='& KLEMS &\\multicolumn{3}{c}{Software} & Modified & KLEMS & R\\&D & Modified \\\\ \n';
fmt{5}='&  Data & Total & Prepack. & Cust. &  Data & & \\\\ \n';
fmt{6}='& (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8)\\\\ \n';
fmt{7}='\\hline \n';
fmt{8}='%s &  %4.1f &  %4.1f & %4.1f   &  %4.1f  & %4.1f & %4.1f & %4.1f & %4.1f \\\\ \n';
fmt{9}='\\hline\\hline \n';
fmt{10}='\\end{tabular} \n';

fname=[outputloc '\TableA6.tex'];
fid=fopen(fname,'w');
for i=1:7
    fprintf(fid,fmt{i});
end
for i=1:3
    fprintf(fid,fmt{8},rownames{i},xx(i,:));
end
for i=9:10
    fprintf(fid,fmt{i});
end
fclose(fid);








