% LF Factor Model Estimated with Gibbs sampling
%
clear;
small = 1.0e-10;
big = 1.0e+5;                  
rng(231386);
this_date = datestr(now,'yyyymmdd');

% Include directory with misc project-specific functions
p1 = path;
path(p1,'m_utilities');


% -- File Directories  
outdir = 'out/';
figdir = 'fig/';
matdir = 'mat/';

% -- Benchmark Model -- 
q=8;
eta = 1.0;   % Prior SD for lambda

% -- Other Models ---
%  q=8;
%  eta = 0.5;   % Prior SD for lambda

%  q=8;
%  eta = 2.0;   % Prior SD for lambda

% q=6;
% eta = 1.0;   % Prior SD for lambda

% ---------------


mlabel = ['lf_' num2str(eta*10) '_' num2str(q)];

% Read data 
% -- Read in Data --- 
read_data_calendar_merged_data;
% Cyclically Adjust Some Series
urate_cyc_adj;

% Sample Period
first_est = [1950 1];
last_est = Last_obs;
ismpl_est = smpl(calvec,first_est,last_est,n_period);
% Some variables
emp_sectoral_data_ca = emp_sectoral_data_ca(ismpl_est==1,:);
tfp_sectoral_data_ca = tfp_sectoral_data_ca(ismpl_est==1,:);
calvec = calvec(ismpl_est==1);
T_obs = size(calvec,1);
n_y = size(emp_sectoral_data,2);

emp_mat = emp_sectoral_data_ca;
tfp_mat = tfp_sectoral_data_ca;
share_emp = emp_shares_avg;
share_tfp = tfp_shares_avg;

lowest_period_years_q = 2*T_obs/(n_period*q);
highest_period_years_q = 2*T_obs/(n_period);

% Construct sample mean and cosine transform, etc
[WT,XE,~] = WT_avg(emp_mat,q);
xbar_emp = XE(1,:);
X_emp = XE(2:end,:);
W = WT(:,2:end)/T_obs;

[WT,XE,xproj] = WT_avg(tfp_mat,q);
xbar_tfp = XE(1,:);
X_tfp = XE(2:end,:);

X = [X_emp X_tfp];

% Some Covariance Matrices
S_I0 = eye(T_obs);
S_I1 = (1/T_obs^2)*rw_cov(T_obs);
SW_I0 = W'*S_I0*W;
SW_I1 = W'*S_I1*W;
diag_SW_I0 = diag(SW_I0);
diag_SW_I1 = diag(SW_I1);

% Priors for Covariance Matrices
% U
nu_prior_u = 0.01;
s2_prior_u = eye(2);

% F
nu_prior_f = 0.01;
s2_prior_f = eye(2);

% --- Prior for lambda
lam_mean_prior_emp = ones(n_y,1);
lam_mean_prior_tfp = ones(n_y,1);
lam_var_prior_1 = (eta^2)*eye(n_y);
m_share_emp = eye(n_y)-share_emp*share_emp'/sum(share_emp.^2);
lam_var_prior_emp = m_share_emp*lam_var_prior_1*m_share_emp';
m_share_tfp = eye(n_y)-share_tfp*share_tfp'/sum(share_tfp.^2);
lam_var_prior_tfp = m_share_tfp*lam_var_prior_1*m_share_tfp';

% Big Matrix
lam_mean_prior = [lam_mean_prior_emp;lam_mean_prior_tfp];
lam_var_prior = [[lam_var_prior_emp zeros(n_y,n_y)];[zeros(n_y,n_y) lam_var_prior_tfp]];

% Prior for g
n_g_grid = 15;
lg_min = log(1);
lg_max = log(500);
lg_grid = linspace(lg_min,lg_max,n_g_grid-1)';
g_grid = [0;exp(lg_grid)];
g_prior = ones(n_g_grid,1)/n_g_grid;

% Initial values of parameters
sigma_u = zeros(2,2,n_y);
for j = 1:n_y
    sigma_u(:,:,j) = eye(2);
end
sigma_f = eye(2);
lam_emp = lam_mean_prior_emp;
lam_tfp = lam_mean_prior_tfp;
jj = multinomial_draws(g_prior,2);
g_f = g_grid(jj);
g_u = NaN(2,n_y);
jj = multinomial_draws(g_prior,n_y);
g_u(1,:) = g_grid(jj)';
jj = multinomial_draws(g_prior,n_y);
g_u(2,:) = g_grid(jj)';

% Initial Values for Covariance Matrix elements
[Vf, Vu] = form_Vf_Vu(diag_SW_I0,diag_SW_I1,g_f,g_u,sigma_f,sigma_u,q,n_y);

% Carry Out Gibbs Draws
% Number of draws
n_burnin = 50000;       % Discarded Draws
n_draws_save = 2500;    % Number of Draws to Save
k_draws = 200;          % Save results every k_draws
itmp = 0;
tic;
kk_draw  = 0;
jj_draw = 0;

lam_draws_emp = NaN(n_y,n_draws_save);
lam_draws_tfp = NaN(n_y,n_draws_save);
f_draws_emp = NaN(q,n_draws_save);
f_draws_tfp = NaN(q,n_draws_save);
sigma_f_draws = NaN(2,2,n_draws_save);
sigma_u_draws = NaN(2,2,n_y,n_draws_save);
g_f_draws = NaN(2,n_draws_save);
g_u_draws = NaN(2,n_y,n_draws_save);

for idraw = 1:n_burnin+n_draws_save*k_draws 
    % --- Step 1: Draw f
    f_draw = zeros(q,2);
    for i = 1:q
        vf = [[Vf(i,1) Vf(i,3)];[Vf(i,3) Vf(i,2)]];
        vu = [[diag(squeeze(Vu(i,1,:))) diag(squeeze(Vu(i,3,:)))];[diag(squeeze(Vu(i,3,:))) diag(squeeze(Vu(i,2,:)))]];
        lam = [[lam_emp zeros(n_y,1)];[zeros(n_y,1) lam_tfp]];
        vy = lam*vf*lam' + vu;   % Variance of Y 
        cy = lam*vf;             % Covariance with factor and tau_u components        
        b = (linsolve(vy,cy))';  % Regression Coefficient
        f_mean = b*X(i,:)';
        f_var = vf-b*cy;
        tmp = f_mean+sqrt_psd(f_var)*randn(2,1);
        f_draw(i,:) = tmp';
    end
    f_emp = f_draw(:,1);
    f_tfp = f_draw(:,2);
    u_emp = X_emp - f_emp*lam_emp';
    u_tfp = X_tfp - f_tfp*lam_tfp';

    % -- Step 2: Draw sigma
    % (a) Sigma_f
    y_emp = f_emp./sqrt(diag_SW_I0 +g_f(1)^2*diag_SW_I1);
    y_tfp = f_tfp./sqrt(diag_SW_I0 + g_f(2)^2*diag_SW_I1);   % Eliminate heteroskedasticity
    sigma_f = draw_sigma_iw([y_emp y_tfp],nu_prior_f,s2_prior_f);
    % (b) Sigma_u
    for j = 1:n_y
        y_emp = u_emp(:,j)./sqrt(diag_SW_I0 + g_u(1,j)^2*diag_SW_I1);
        y_tfp = u_tfp(:,j)./sqrt(diag_SW_I0 + g_u(2,j)^2*diag_SW_I1);   % Eliminate heteroskedasticity
        sigma_u(:,:,j) = draw_sigma_iw([y_emp y_tfp],nu_prior_u,s2_prior_u);
    end

    % -- Step 3: Draw g
    % F
    g_f = draw_g(f_emp,f_tfp,sigma_f,g_grid,g_prior,diag_SW_I0,diag_SW_I1);
    % u
    for j = 1:n_y
        g_u(:,j) = draw_g(u_emp(:,j),u_tfp(:,j),squeeze(sigma_u(:,:,j)),g_grid,g_prior,diag_SW_I0,diag_SW_I1);
    end

    % Update Covariance Matrices using new g and sigma
    [Vf, Vu] = form_Vf_Vu(diag_SW_I0,diag_SW_I1,g_f,g_u,sigma_f,sigma_u,q,n_y);

    % -- Step 4: Draw lambda
    Y_emp = X_emp(:);  % Vectorized
    Y_tfp = X_tfp(:);
    Z_emp = kron(eye(n_y),f_emp(:));
    Z_tfp = kron(eye(n_y),f_tfp(:));
    Y = [Y_emp;Y_tfp];
    Z = [[Z_emp zeros(q*n_y,n_y)];[zeros(q*n_y,n_y) Z_tfp]];
    v11 = squeeze(Vu(:,1,:));
    v12 = squeeze(Vu(:,3,:));
    v22 = squeeze(Vu(:,2,:));
    vu = [[diag(v11(:)) diag(v12(:))];[diag(v12(:)) diag(v22(:))]];
    mean_y = Z*lam_mean_prior;
    var_y = Z*lam_var_prior*Z'+vu;
    cvar_y_lam = Z*lam_var_prior;
    b = (linsolve(var_y,cvar_y_lam))';
    lam_mean = lam_mean_prior+b*(Y-mean_y);
    lam_var = lam_var_prior-b*cvar_y_lam;
    lam = lam_mean + sqrt_psd(lam_var)*randn(2*n_y,1);
    lam_emp = lam(1:n_y);
    lam_tfp = lam(n_y+1:2*n_y);

    % Save Draws;
    if idraw > n_burnin
        kk_draw = kk_draw+1;
        if kk_draw == k_draws
            jj_draw = jj_draw+1;
            kk_draw = 0;
            lam_draws_emp(:,jj_draw) = lam_emp;
            lam_draws_tfp(:,jj_draw) = lam_tfp;
            f_draws_emp(:,jj_draw) = f_emp;
            f_draws_tfp(:,jj_draw) = f_tfp;
            sigma_f_draws(:,:,jj_draw) = sigma_f;
            sigma_u_draws(:,:,:,jj_draw) = sigma_u;
            g_f_draws(:,jj_draw) = g_f;
            g_u_draws(:,:,jj_draw) = g_u;
        end
        itmp=itmp+1;
        if itmp == 10000
            itmp=0;
            fprintf('  Number of Draws: %6i    ',idraw);
            toc
            tic;
        end      
    end
end

str_tmp = [matdir 'lam_draws_emp_' mlabel]; save(str_tmp,'lam_draws_emp');
str_tmp = [matdir 'lam_draws_tfp_' mlabel]; save(str_tmp,'lam_draws_tfp');
str_tmp = [matdir 'f_draws_emp_' mlabel]; save(str_tmp,'f_draws_emp');
str_tmp = [matdir 'f_draws_tfp_' mlabel]; save(str_tmp,'f_draws_tfp');
str_tmp = [matdir 'sigma_f_draws_' mlabel]; save(str_tmp,'sigma_f_draws');
str_tmp = [matdir 'sigma_u_draws_' mlabel]; save(str_tmp,'sigma_u_draws');
str_tmp = [matdir 'g_f_draws_' mlabel]; save(str_tmp,'g_f_draws');
str_tmp = [matdir 'g_u_draws_' mlabel]; save(str_tmp,'g_u_draws');

% Save information on priors
str_tmp = [matdir 'nu_prior_u_' mlabel]; save(str_tmp,'nu_prior_u');
str_tmp = [matdir 's2_prior_u_' mlabel]; save(str_tmp,'s2_prior_u');
str_tmp = [matdir 'nu_prior_f_' mlabel]; save(str_tmp,'nu_prior_f');
str_tmp = [matdir 's2_prior_f_' mlabel]; save(str_tmp,'s2_prior_f');
str_tmp = [matdir 'lam_mean_prior_emp_' mlabel]; save(str_tmp,'lam_mean_prior_emp');
str_tmp = [matdir 'lam_var_prior_emp_' mlabel]; save(str_tmp,'lam_var_prior_emp');
str_tmp = [matdir 'lam_mean_prior_tfp_' mlabel]; save(str_tmp,'lam_mean_prior_tfp');
str_tmp = [matdir 'lam_var_prior_tfp_' mlabel]; save(str_tmp,'lam_var_prior_tfp');
str_tmp = [matdir 'g_grid_' mlabel]; save(str_tmp,'g_grid');
str_tmp = [matdir 'g_prior_' mlabel]; save(str_tmp,'g_prior');


% Reset path
path(p1);

% -------------------- Some Functions Used ------------------

function [sigma_draw] = draw_sigma_iw(y,nu_prior,s2_prior)
    % Draw Sigma using inverse Wishart prior
    %
    T = size(y,1);
    %n = size(y,2);
    SSR_mat = y'*y;
    SSR_prior = nu_prior*s2_prior;
    SSR = SSR_mat + SSR_prior;
    nu = T + nu_prior;
    sigma_draw = iwishrnd(SSR,nu);
end

% function [sigma_draw] = draw_sigma_iw_prior(nu_prior,s2_prior)
%     % Draw Sigma using inverse Wishart prior
%     SSR = nu_prior*s2_prior;
%     nu = nu_prior;
%     sigma_draw = iwishrnd(SSR,nu);
% end

function [Vf, Vu] = form_Vf_Vu(diag_SW_I0,diag_SW_I1,g_f,g_u,sigma_f,sigma_u,q,n_y) 
    % Vf is q x 3 ... two variances and then covariance 
    Vf = NaN(q,3);
    Vf(:,1) = sigma_f(1,1)*(diag_SW_I0 + g_f(1)^2*diag_SW_I1);
    Vf(:,2) = sigma_f(2,2)*(diag_SW_I0 + g_f(2)^2*diag_SW_I1);
    Vf(:,3) = sigma_f(1,2)*sqrt((diag_SW_I0 + g_f(1)^2*diag_SW_I1).*(diag_SW_I0 + g_f(2)^2*diag_SW_I1));
    % Vu is q x 3 x n_y
    Vu = NaN(q,3,n_y);
    for j = 1:n_y
        Vu(:,1,j) = sigma_u(1,1,j)*(diag_SW_I0 + g_u(1,j)^2*diag_SW_I1);
        Vu(:,2,j) = sigma_u(2,2,j)*(diag_SW_I0 + g_u(2,j)^2*diag_SW_I1);
        Vu(:,3,j) = sigma_u(1,2,j)*sqrt((diag_SW_I0 + g_u(1,j)^2*diag_SW_I1).*(diag_SW_I0 + g_u(2,j)^2*diag_SW_I1));
    end
end

function [lf] = lf_biv_g(x1,x2,g1,g2,chol_sigma_inv,diag_SW_I0,diag_SW_I1)
    s1 = sqrt(diag_SW_I0 + g1^2*diag_SW_I1);
    s2 = sqrt(diag_SW_I0 + g2^2*diag_SW_I1);
    v1 = x1./s1;
    v2 = x2./s2;
    d1 = prod(s1);
    d2 = prod(s2);
    u = [v1 v2]*chol_sigma_inv';
    S = sum(sum(u.^2));
    lf = (1/(d1*d2))*exp(-0.5*S);
end

function [g_draw] = draw_g(x1,x2,sigma,g_grid,g_prior,diag_SW_I0,diag_SW_I1)
    n_g = size(g_grid,1);
    plf = NaN(n_g^2,1);
    gg = NaN(n_g^2,2);
    chol_sigma_inv = chol(inv(sigma));
    jj = 1;
    for i = 1:n_g
        for j = 1:n_g
            lf = lf_biv_g(x1,x2,g_grid(i),g_grid(j),chol_sigma_inv,diag_SW_I0,diag_SW_I1);
            plf(jj) = lf*g_prior(i)*g_prior(j);
            gg(jj,1) = g_grid(i);
            gg(jj,2) = g_grid(j);
            jj = jj+1;
        end
    end
    p_post = plf/sum(plf);
    jj = multinomial_draws(p_post,1);
    g_draw = gg(jj,:)';

end