

% Summarize Results .. Master Program
%
close all
clear;
small = 1.0e-10;
big = 1.0e+5;                  
rng(63761);
this_date = datestr(now,'yyyymmdd');

% Include directory with misc project-specific functions
p1 = path;
path(p1,'m_utilities');
 
% -- File Directories  
outdir = 'out/';
figdir = 'fig/';
matdir = 'mat/';

% Read data
Read_data;

% Parameters for Benchmark model calculations
q=8;
eta = 1.0;     % Prior SD for lambda
mlabel = ['lf_' num2str(eta*10) '_' num2str(q)];

% Construct LF trends and Moving-averages
nma_fig = 11;  % MA order for figures
q = 8;         % q value for LF trend
lf_ma_components;

% Summarize the posterior Table and Figures used in paper
% Shade Colors
Cl1 = 'LightPink';
Cl2 = 'PowderBlue';

% Draw Results from MCMC
str_tmp = [matdir 'lam_draws_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_draws_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'f_draws_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'f_draws_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'sigma_f_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'sigma_u_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_f_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_u_draws_' mlabel]; load(str_tmp);

% Save information on priors
str_tmp = [matdir 'nu_prior_u_' mlabel]; load(str_tmp);
str_tmp = [matdir 's2_prior_u_' mlabel]; load(str_tmp);
str_tmp = [matdir 'nu_prior_f_' mlabel]; load(str_tmp);
str_tmp = [matdir 's2_prior_f_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_mean_prior_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_var_prior_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_mean_prior_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_var_prior_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_grid_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_prior_' mlabel]; load(str_tmp);
n_g_grid = size(g_grid,1);
n_draws = size(lam_draws_emp,2);

% Some Covariance Matrices~
[WT,~,~] = WT_avg(zeros(T_obs,1),q);
W = WT(:,2:end)/T_obs;
S_I0 = eye(T_obs);
S_I1 = (1/T_obs^2)*rw_cov(T_obs);
SW_I0 = W'*S_I0*W;
SW_I1 = W'*S_I1*W;
diag_SW_I0 = diag(SW_I0);
diag_SW_I1 = diag(SW_I1);

% Summary Table 

% construct a table with 68% credible sets
lam_emp = NaN(n_y,3);
lam_tfp = NaN(n_y,3);
r2_emp = NaN(n_y,3);
r2_tfp = NaN(n_y,3);
cor_emp_tfp = NaN(n_y,3);
var_emp_u_all = NaN(n_y,n_draws);
var_tfp_u_all = NaN(n_y,n_draws);
cov_emp_tfp_u_all = NaN(n_y,n_draws);

for j = 1:n_y
    lam_emp(j,:) = pctile(lam_draws_emp(j,:)',[0.5 1/6 5/6]);
    lam_tfp(j,:) = pctile(lam_draws_tfp(j,:)',[0.5 1/6 5/6]);

    % Compute Variance Components
    lam_emp_2 = (lam_draws_emp(j,:).^2)';
    lam_tfp_2 = (lam_draws_tfp(j,:).^2)';

    sigma_f_emp = squeeze(sigma_f_draws(1,1,:));
    g_emp_f = g_f_draws(1,:)';
    var_emp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.^2);
    var_emp_f = lam_emp_2.*sigma_f_emp.*var_emp_f;
    sigma_u_emp = squeeze(sigma_u_draws(1,1,j,:));
    g_emp_u = squeeze(g_u_draws(1,j,:));
    var_emp_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_u.^2);
    var_emp_u = sigma_u_emp.*var_emp_u;
    R2 = var_emp_f./(var_emp_f + var_emp_u);
    r2_emp(j,:) = pctile(R2,[0.5 1/6 5/6]);

    sigma_f_tfp = squeeze(sigma_f_draws(2,2,:));
    g_tfp_f = g_f_draws(2,:)';
    var_tfp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_f.^2);
    var_tfp_f = lam_tfp_2.*sigma_f_tfp.*var_tfp_f;
    sigma_u_tfp = squeeze(sigma_u_draws(2,2,j,:));
    g_tfp_u = squeeze(g_u_draws(2,j,:));
    var_tfp_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_u.^2);
    var_tfp_u = sigma_u_tfp.*var_tfp_u;
    R2 = var_tfp_f./(var_tfp_f + var_tfp_u);
    r2_tfp(j,:) = pctile(R2,[0.5 1/6 5/6]);

    % Correlation of u components;
    sigma_u_emp_tfp = squeeze(sigma_u_draws(1,2,j,:));
    cov_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_u.*g_tfp_u);
    cov_u = sigma_u_emp_tfp.*cov_u;
    cor_u = cov_u./sqrt(var_emp_u .*var_tfp_u);
    cor_emp_tfp(j,:) = pctile(cor_u,[0.5 1/6 5/6]);

    % Save
    var_emp_u_all(j,:) = var_emp_u;
    var_tfp_u_all(j,:) = var_tfp_u;
    cov_emp_tfp_u_all(j,:) = cov_u;
end

% Plot sector-specific contributions to aggregates by sector
% Decompose aggregates into common unique components
e_draws_emp = NaN(n_y,q,n_draws);
e_draws_tfp = NaN(n_y,q,n_draws);
for i = 1:n_y
    e_draws_emp(i,:,:)=repmat(X_emp_sec(:,i),1,n_draws)-repmat(lam_draws_emp(i,:),q,1).*f_draws_emp;
    e_draws_tfp(i,:,:)=repmat(X_tfp_sec(:,i),1,n_draws)-repmat(lam_draws_tfp(i,:),q,1).*f_draws_tfp;
end
X_agg_emp_f = f_draws_emp.*repmat(lam_draws_emp(i,:),q,1);
X_agg_tfp_f = f_draws_tfp.*repmat(lam_draws_tfp(i,:),q,1);
X_agg_emp_e = NaN(n_y,q,n_draws);
X_agg_tfp_e = NaN(n_y,q,n_draws);
for i = 1:n_y
    X_agg_emp_e(i,:,:) = share_emp(i)*e_draws_emp(i,:,:);
    X_agg_tfp_e(i,:,:) = share_tfp(i)*e_draws_tfp(i,:,:);
end

% Compute and plot results Value-added results
% Read in the multipliers from Andrew
filename = 'Long Run Multipliers.xlsx';  
xlsname = ['../data/' filename];
lrm_tfp = xlsread(xlsname,'A1:A16');  
lrm_emp = xlsread(xlsname,'B1:B16');
lrm_tfp_direct = xlsread(xlsname,'C1:C16');  
lrm_emp_direct = xlsread(xlsname,'E1:E16');
lrm_tfp_base = lrm_tfp;
lrm_emp_base = lrm_emp;

% Construct model-based decomposition of GDP
% GDP Data and LR trends
% va_agg = GDP
% xproj_va_agg = lf component
xproj_va_agg_emp = xproj_emp_sec*lrm_emp;
xproj_va_agg_tfp = xproj_tfp_sec*lrm_tfp;
xproj_va_agg_model = xproj_va_agg_emp+xproj_va_agg_tfp;
xproj_va_agg_emp_de = xproj_emp_sec*lrm_emp_direct;
xproj_va_agg_tfp_de = xproj_tfp_sec*lrm_tfp_direct;
xproj_va_agg_model_de = xproj_va_agg_emp_de+xproj_va_agg_tfp_de;

% Carry out decomposition (demeaned throughout) 
xproj_dm_va_agg_emp = xproj_dm_emp_sec*lrm_emp;
xproj_dm_va_agg_tfp = xproj_dm_tfp_sec*lrm_tfp;
xproj_dm_va_agg_model = xproj_dm_va_agg_emp+xproj_dm_va_agg_tfp;

tmp = lrm_emp'*lam_draws_emp;
tmp = repmat(tmp,q,1).*f_draws_emp;
tmp = WT(:,2:end)*tmp;
xproj_dm_va_agg_emp_f = pctile(tmp',[0.5 1/6 5/6])';

tmp = lrm_tfp'*lam_draws_tfp;
tmp = repmat(tmp,q,1).*f_draws_tfp;
tmp = WT(:,2:end)*tmp;
xproj_dm_va_agg_tfp_f = pctile(tmp',[0.5 1/6 5/6])';

ee_draws_emp = NaN(q,n_draws);
ee_draws_tfp = NaN(q,n_draws);
for iq = 1:q
    tmp = squeeze(e_draws_emp(:,iq,:));
    ee_draws_emp(iq,:)=lrm_emp'*tmp;
    tmp = squeeze(e_draws_tfp(:,iq,:));
    ee_draws_tfp(iq,:)=lrm_tfp'*tmp;
end
tmp = WT(:,2:end)*ee_draws_emp;
xproj_dm_va_agg_emp_u = pctile(tmp',[0.5 1/6 5/6])';
tmp = WT(:,2:end)*ee_draws_tfp;
xproj_dm_va_agg_tfp_u = pctile(tmp',[0.5 1/6 5/6])';

xproj_dm_va_agg_f = xproj_dm_va_agg_emp_f + xproj_dm_va_agg_tfp_f;
xproj_dm_va_agg_u = xproj_dm_va_agg_emp_u + xproj_dm_va_agg_tfp_u;

% Compute posteriors for lambdas for GDP and Compute R-squared for
% common factors
lam_emp_va_draws = (lrm_emp'*lam_draws_emp)';
lam_emp_va = pctile(lam_emp_va_draws,[0.5 1/6 5/6]);
lam_tfp_va_draws = (lrm_tfp'*lam_draws_tfp)';
lam_tfp_va = pctile(lam_tfp_va_draws,[0.5 1/6 5/6]);

% Plot Sector-specific contributions by sector
X_va_agg_emp_e = NaN(n_y,q,n_draws);
X_va_agg_tfp_e = NaN(n_y,q,n_draws);
for i = 1:n_y
    X_va_agg_emp_e(i,:,:) = lrm_emp(i)*e_draws_emp(i,:,:);
    X_va_agg_tfp_e(i,:,:) = lrm_tfp(i)*e_draws_tfp(i,:,:);
end
X_va_agg_e_baseline = X_va_agg_emp_e + X_va_agg_tfp_e;

x = calvec;
x2 = [x;flipud(x)];


% New LR multipliers
filename = 'Long Run Multipliers - PBS Experiment 2.xlsx';  
xlsname = ['../data/' filename];
lrm_tfp2 = xlsread(xlsname,'A1:A16');  
lrm_emp2 = xlsread(xlsname,'B1:B16');

% load measurement error series
load ../data/KLEMS_1947_2018_PBS.mat;
epsPBS = -100*epsPBS;
q = 8;
[WT_eps,XE,xproj] = WT_avg(epsPBS,q);
xbar = XE(1,:);
X = XE(2:end,:);
W = WT_eps(:,2:end)/T_obs;
xma = NaN(size(y_mat));
tmp = ma(y_mat,nma_fig);
aa = (nma_fig-1)/2;
xma(aa+1:end-aa,:)=tmp(nma_fig:end,:);
xbar_eps = xbar(1);
X_eps = X(:,1);
xproj_eps = zeros(71,16);
xproj_eps(:,12) = xproj(:,1);

figure
plot([epsPBS,xproj_eps(:,12)])

% -- Load Model Parameters -- %
load('../data/data_io_cap/IO_2015');             % loading parameters from the Make and Use Tables: theta, phi
load('../data/data_io_cap/capflow');             % loading parameters from the capital flow tables   
N = 16;
gma_d = diag(gma);
alpha_d = diag(alpha);

capPi = ((eye(N) - phi*(eye(N)-gma_d))/gma_d)';
Xi = ((inv(eye(N) - gma_d*alpha_d*omega' - (eye(N)-gma_d)*phi'))*gma_d)';

xproj_eps = (Xi'*xproj_eps')';





fig = figure;
for i = 1:n_y
    str = char(sector_names(i));
    e_tmp = squeeze(X_va_agg_e_baseline(i,:,:));
    e_proj = WT(:,2:end)*e_tmp;
    e_pct = pctile(e_proj',[0.5 1/6 5/6])';
    
    e_pct1 = e_pct;
    e_pct1(:,1) = e_pct(:,1) + xproj_eps(3:end,i)*lrm_tfp(i);

    
    subplot(4,4,i);

    hold on;
    z = [e_pct(:,2);flipud(e_pct(:,3))];
    ii = ~isnan(z);
    plot(calvec,e_pct(:,1),'- r','LineWidth',1)
    plot(calvec,e_pct1(:,1),'-- k', 'LineWidth',2)
    plot(calvec,e_pct1(:,1)*lrm_tfp2(i)/lrm_tfp(i),'- b', 'LineWidth',2)
    hold off;
    xlim([1950 2020]);
    title(str);
end
legend('Baseline','Mismeasured PBS Output','Mismeasured PBS Output')
orient landscape;
print(fig, [figdir, 'PBS Experiments'], '-dpdf','-bestfit');
% close(gcf);


%%
j = 0;
fig = figure;
alphabet = 'a':'c';
for i = [4 5 12]
    j = j +1;
    subplot(1,3,j)
%     fig = figure('Units','Inches','Position',[1 1 2.05 3]);
    str = char(sector_names(i));
    e_tmp = squeeze(X_va_agg_e_baseline(i,:,:));
    e_proj = WT(:,2:end)*e_tmp;
    e_pct = pctile(e_proj',[0.5 1/6 5/6])';
    

    e_pct1 = e_pct;
    e_pct1(:,1) = e_pct(:,1) + xproj_eps(3:end,i)*lrm_tfp(i);

    hold on;
    z = [e_pct(:,2);flipud(e_pct(:,3))];
    ii = ~isnan(z);
    plot(calvec,e_pct(:,1),'- r','LineWidth',1)
    plot(calvec,e_pct1(:,1),'-- k', 'LineWidth',2)
    plot(calvec,e_pct1(:,1)*lrm_tfp2(i)/lrm_tfp(i),'- b', 'LineWidth',2)
    hold off;
    xlim([1950 2020]);
    title(str);
    box on;
    if i == 12 || i == 4
        %ylim([-0.6 1])
        %yticks(-0.6:0.2:1)
    end
    if i == 4
        legend({'Baseline','Mismeasured',['Mismeasured and' newline 'Misclassified']},'Location','Northeast','FontSize',6)
    end

end
print(fig, [figdir, 'Figure_13'], '-dpdf','-bestfit');
close(gcf);
