% Set up data and calendars Read in merged data from AH
n_period = 1;
First_obs = [1947 1];
Last_obs = [2018 1];
First_share = [1950 1];
% ----------- Sample Period, Calendars and so forth
[dnobs,calvec,calds] = calendar_make(First_obs,Last_obs,n_period);


% ----------- Features of Data Set ---------
filename = 'KLEMSbea16_1947_1963_1987_2018';
fname = ['../Data/' filename];
load(fname,'SecName','y','v','k','n','m','yq','vq','kq','nq','mq','dzy','dzv','tt'); 
ns = size(y,2);  % number of series

% Growth rates
dy = 100*dif(log(y),1);
dv = 100*dif(log(v),1);
dk = 100*dif(log(k),1);
dn = 100*dif(log(n),1);
dm = 100*dif(log(m),1);
dyq = 100*dif(log(yq),1);
dvq = 100*dif(log(vq),1);
dkq = 100*dif(log(kq),1);
dnq = 100*dif(log(nq),1);
dmq = 100*dif(log(mq),1);
dzv(1,:) = NaN;

% Rename
va_sectoral_data = dvq;
tfp_sectoral_data = 100*dzv;
emp_sectoral_data = dnq;
cap_sectoral_data = dkq;
sector_labels = SecName;

% Sample period for computing average shares
ismpl_shares = smpl(calvec,First_share,Last_obs,n_period);
ismpl_shares_first = smpl(calvec,[1950 1],[1964 1],n_period);
ismpl_shares_last = smpl(calvec,[2004 1],[2018 1],n_period);

% VA Shares
tmp = v./repmat(sum(v,2),1,ns);
va_shares_chain = NaN(dnobs,ns);
va_shares_chain(2:end,:) = (tmp(2:end,:) + tmp(1:end-1,:))/2;
va_shares_avg = mean(tmp(ismpl_shares==1,:),1)';
va_shares_avg_first = mean(tmp(ismpl_shares_first==1,:),1)';
va_shares_avg_last = mean(tmp(ismpl_shares_last==1,:),1)';

% EMP Shares
tmp = n./repmat(sum(n,2),1,ns);
emp_shares_chain = NaN(dnobs,ns);
emp_shares_chain(2:end,:) = (tmp(2:end,:) + tmp(1:end-1,:))/2;
emp_shares_avg = mean(tmp(ismpl_shares==1,:),1)';

% TFP Shares
tfp_shares_chain = va_shares_chain;
tfp_shares_avg = va_shares_avg;

% Aggregates
% Compute Aggregate VA ... Use VA share
va_aggregate_data_chain = sum(va_sectoral_data.*va_shares_chain,2);
va_aggregate_data_fixed_weight = va_sectoral_data*va_shares_avg;
va_aggregate_data_first = va_sectoral_data*va_shares_avg_first;
va_aggregate_data_last = va_sectoral_data*va_shares_avg_last;

% Compute Aggregate TFP ... Use VA share
tfp_aggregate_data_chain = sum(tfp_sectoral_data.*tfp_shares_chain,2);
tfp_aggregate_data_fixed_weight = tfp_sectoral_data*tfp_shares_avg;

% Compute Aggregate Labor
emp_aggregate_data_chain = sum(emp_sectoral_data.*emp_shares_chain,2);
emp_aggregate_data_fixed_weight = emp_sectoral_data*emp_shares_avg;

% Read in Labor Force data
filename = 'CLF16OV.xlsx';  
xlsname = ['../data/' filename];
sheet='FRED Graph';
lf_level = xlsread(xlsname,sheet,'B12:B83');   % Annual Data 1948-2019
lf_level = [NaN;lf_level]; % Pad with missing value so it starts in 1947
dlf = 100*dif(log(lf_level),1);
% Align Calendar
[~,calvec_tmp,~] = calendar_make([1947 1],[2019 1],n_period);
ismpl = smpl(calvec_tmp,First_obs,Last_obs,n_period);
dlf = dlf(ismpl==1);

% Construct emp series relative to dlf
emp_sectoral_data_dlf = emp_sectoral_data-repmat(dlf,1,size(emp_sectoral_data,2));
emp_aggregate_data_chain_dlf = emp_aggregate_data_chain-dlf;
emp_aggregate_data_fixed_weight_dlf = emp_aggregate_data_fixed_weight-dlf;

% Update calendar;
short_names = {...
    'Agr' ...
    'Min' ...
    'Utl' ...
    'Con' ...
    'DurG' ...
    'NdG' ...
    'WT' ...
    'RT' ...
    'TW' ...
    'Inf' ...
    'F(x-H)' ...
    'PBS' ...
    'EdHe' ...
    'AEFS' ...
    'OthS'...
    'Hous' ...
 }';

sector_names = {...
	'Agriculture' ...
    'Mining' ...
    'Utilities' ...
    'Construction' ...
    'Durable Goods' ...
    'Nondurable Goods' ...
    'Wholesale Trade' ...
    'Retail Trade' ...
    'Trans. & Ware.' ...
    'Information' ...
    'FIRE (x-Housing)' ...
    'PBS' ...
    'Educ. & Health' ...
    'Arts, Ent., & Food Svc.' ...
    'Other Services (x-Gov)'...
    'Housing' ...
 }';


% Save Variable Series 
slist = {...
    'sector_labels' ...
    'short_names' ...
    'va_sectoral_data' ... 
    'va_aggregate_data_chain' ...
    'va_aggregate_data_fixed_weight' ...
    'va_aggregate_data_first' ...
    'va_aggregate_data_last' ...
    'va_shares_chain' ...
    'va_shares_avg' ...
    'tfp_sectoral_data' ... 
    'tfp_aggregate_data_chain' ...
    'tfp_aggregate_data_fixed_weight' ...
    'tfp_shares_chain' ...
    'tfp_shares_avg' ...
    'emp_sectoral_data' ... 
    'emp_aggregate_data_chain' ...
    'emp_aggregate_data_fixed_weight' ...
    'emp_shares_chain' ...
    'emp_shares_avg' ...
    'cap_sectoral_data'...
    'dnobs' ...
    'calvec' ...
    'calds' ...
    'dlf' ...
    'emp_sectoral_data_dlf' ... 
    'emp_aggregate_data_chain_dlf' ...
    'emp_aggregate_data_fixed_weight_dlf' ...   
    'sector_names' ...
}';

str_tmp = [matdir 'slist'];
save(str_tmp,'slist');
for iseries = 1:size(slist,1)
  ustr = char(slist(iseries));
  %str_tmp = [matdir ustr];
  str_tmp1 = 'save(str_tmp,''';
  str_tmp2 = ''');';
  eval([str_tmp1 ustr str_tmp2]);
end


% Load Variables and Give Standard Names 
str_tmp = [matdir 'slist'];
load(str_tmp); 
for iseries = 1:size(slist,1)
 ustr = char(slist(iseries));
 str_tmp = [matdir ustr];
 load(str_tmp);
end