% Summarize the posterior Table and Figures used in paper
% Shade Colors
Cl1 = 'LightPink';
Cl2 = 'PowderBlue';

% Draw Results from MCMC
str_tmp = [matdir 'lam_draws_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_draws_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'f_draws_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'f_draws_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'sigma_f_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'sigma_u_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_f_draws_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_u_draws_' mlabel]; load(str_tmp);

% Save information on priors
str_tmp = [matdir 'nu_prior_u_' mlabel]; load(str_tmp);
str_tmp = [matdir 's2_prior_u_' mlabel]; load(str_tmp);
str_tmp = [matdir 'nu_prior_f_' mlabel]; load(str_tmp);
str_tmp = [matdir 's2_prior_f_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_mean_prior_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_var_prior_emp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_mean_prior_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'lam_var_prior_tfp_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_grid_' mlabel]; load(str_tmp);
str_tmp = [matdir 'g_prior_' mlabel]; load(str_tmp);
n_g_grid = size(g_grid,1);
n_draws = size(lam_draws_emp,2);

% Some Covariance Matrices~
[WT,~,~] = WT_avg(zeros(T_obs,1),q);
W = WT(:,2:end)/T_obs;
S_I0 = eye(T_obs);
S_I1 = (1/T_obs^2)*rw_cov(T_obs);
SW_I0 = W'*S_I0*W;
SW_I1 = W'*S_I1*W;
diag_SW_I0 = diag(SW_I0);
diag_SW_I1 = diag(SW_I1);

% Summary Table 

% construct a table with 68% credible sets
lam_emp = NaN(n_y,3);
lam_tfp = NaN(n_y,3);
r2_emp = NaN(n_y,3);
r2_tfp = NaN(n_y,3);
cor_emp_tfp = NaN(n_y,3);
var_emp_u_all = NaN(n_y,n_draws);
var_tfp_u_all = NaN(n_y,n_draws);
cov_emp_tfp_u_all = NaN(n_y,n_draws);

for j = 1:n_y
    lam_emp(j,:) = pctile(lam_draws_emp(j,:)',[0.5 1/6 5/6]);
    lam_tfp(j,:) = pctile(lam_draws_tfp(j,:)',[0.5 1/6 5/6]);

    % Compute Variance Components
    lam_emp_2 = (lam_draws_emp(j,:).^2)';
    lam_tfp_2 = (lam_draws_tfp(j,:).^2)';

    sigma_f_emp = squeeze(sigma_f_draws(1,1,:));
    g_emp_f = g_f_draws(1,:)';
    var_emp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.^2);
    var_emp_f = lam_emp_2.*sigma_f_emp.*var_emp_f;
    sigma_u_emp = squeeze(sigma_u_draws(1,1,j,:));
    g_emp_u = squeeze(g_u_draws(1,j,:));
    var_emp_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_u.^2);
    var_emp_u = sigma_u_emp.*var_emp_u;
    R2 = var_emp_f./(var_emp_f + var_emp_u);
    r2_emp(j,:) = pctile(R2,[0.5 1/6 5/6]);

    sigma_f_tfp = squeeze(sigma_f_draws(2,2,:));
    g_tfp_f = g_f_draws(2,:)';
    var_tfp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_f.^2);
    var_tfp_f = lam_tfp_2.*sigma_f_tfp.*var_tfp_f;
    sigma_u_tfp = squeeze(sigma_u_draws(2,2,j,:));
    g_tfp_u = squeeze(g_u_draws(2,j,:));
    var_tfp_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_u.^2);
    var_tfp_u = sigma_u_tfp.*var_tfp_u;
    R2 = var_tfp_f./(var_tfp_f + var_tfp_u);
    r2_tfp(j,:) = pctile(R2,[0.5 1/6 5/6]);

    % Correlation of u components;
    sigma_u_emp_tfp = squeeze(sigma_u_draws(1,2,j,:));
    cov_u = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_u.*g_tfp_u);
    cov_u = sigma_u_emp_tfp.*cov_u;
    cor_u = cov_u./sqrt(var_emp_u .*var_tfp_u);
    cor_emp_tfp(j,:) = pctile(cor_u,[0.5 1/6 5/6]);

    % Save
    var_emp_u_all(j,:) = var_emp_u;
    var_tfp_u_all(j,:) = var_tfp_u;
    cov_emp_tfp_u_all(j,:) = cov_u;
end

% -- TABLE Posterior -- %'%
outfile_name    = [outdir, 'Table_03_' mlabel '.csv'];
fileID          = fopen(outfile_name,'w');
for j = 1:n_y
    fprintf(fileID,'%5.2f (%5.2f %5.2f),',lam_emp(j,:));
    fprintf(fileID,'%5.2f (%5.2f %5.2f),',lam_tfp(j,:));
    fprintf(fileID,'%5.2f (%5.2f %5.2f),',r2_emp(j,:));
    fprintf(fileID,'%5.2f (%5.2f %5.2f),',r2_tfp(j,:));
    fprintf(fileID,'%5.2f (%5.2f %5.2f) \n',cor_emp_tfp(j,:));
end

% Compute R2 and correlation for aggregates
var_emp_u_agg =((share_emp.^2)'*var_emp_u_all)';
g_emp_f = g_f_draws(1,:)';
sigma_f_emp = squeeze(sigma_f_draws(1,1,:));
var_emp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.^2);
var_emp_f = sigma_f_emp.*var_emp_f;
R2 = var_emp_f./(var_emp_f + var_emp_u_agg);
r2_emp_agg = pctile(R2,[0.5 1/6 5/6]);

var_tfp_u_agg = ((share_tfp.^2)'*var_tfp_u_all)';
g_tfp_f = g_f_draws(2,:)';
sigma_f_tfp = squeeze(sigma_f_draws(2,2,:));
var_tfp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_f.^2);
var_tfp_f = sigma_f_tfp.*var_tfp_f;
R2 = var_tfp_f./(var_tfp_f + var_tfp_u_agg);
r2_tfp_agg = pctile(R2,[0.5 1/6 5/6]);

% Correlation of common component
sigma_f_emp_tfp = squeeze(sigma_f_draws(1,2,:));
cov_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.*g_tfp_f);
cov_f = sigma_f_emp_tfp.*cov_f;
cor_f = cov_f./sqrt(var_emp_f .*var_tfp_f);
cor_emp_tfp_agg = pctile(cor_f,[0.5 1/6 5/6]);

fprintf(fileID,'\n\n 1, 1,');
fprintf(fileID,'%5.2f (%5.2f %5.2f),',r2_emp_agg);
fprintf(fileID,'%5.2f (%5.2f %5.2f),',r2_tfp_agg);
fprintf(fileID,'%5.2f (%5.2f %5.2f) \n',cor_emp_tfp_agg);   

% Miscellaneous numbers
fprintf(fileID,'\n\n\n'); 
% Width of 68% Credible Sets .. posterior
w_post_emp = mean(lam_emp(:,3)-lam_emp(:,2));
w_post_tfp = mean(lam_tfp(:,3)-lam_tfp(:,2));
fprintf(fileID,'Width of 68% CI \n'); %#ok<CTPCT>
fprintf(fileID,'   Labor (post): %5.2f \n',w_post_emp);
fprintf(fileID,'   TFP (post): %5.2f \n',w_post_tfp);
n_ord = -2*norminv(1/6);
w_prior_emp = n_ord*mean(sqrt(diag(lam_var_prior_emp)));
w_prior_tfp = n_ord*mean(sqrt(diag(lam_var_prior_tfp)));
fprintf(fileID,'   Labor (prior): %5.2f \n',w_prior_emp);
fprintf(fileID,'   TFP (prior): %5.2f \n',w_prior_tfp);

fclose(fileID);

% Figure .. Decompose aggregate into common and sector-specific components
% Labor
fig = figure;
x = calvec;
x2 = [x;flipud(x)];
subplot(2,3,1);
plot(calvec,emp_agg-mean(emp_agg),'- k','LineWidth',1);
hold on;
plot(calvec,xproj_dm_emp_agg,'- b','LineWidth',2);
hold off;
title('(a) Aggregate Labor');
ylim([-2.5 2.0]);
xlim([1950 2020]);
legend('Data (demeaned)','Low frequency trend','Location','SouthWest');
subplot(2,3,2);
f_proj = WT(:,2:end)*f_draws_emp;  % This uses share'lambda = 1
f_pct = pctile(f_proj',[0.5 1/6 5/6])';
y_proj = WT(:,2:end)*X_emp_sec*share_emp;
plot(calvec,y_proj,'LineWidth',2);
hold on;
z = [f_pct(:,2);flipud(f_pct(:,3))];
fill(x2,z,rgb(Cl1),'EdgeColor','none');
plot(calvec,f_pct(:,1),'- r','LineWidth',2);
plot(calvec,y_proj,'- b','LineWidth',2);
hold off;
ylim([-2.5 2.0]);
xlim([1950 2020]);
title('(b) Labor: Common');
subplot(2,3,3);
y_proj = WT(:,2:end)*X_emp_sec*share_emp;
f_proj = WT(:,2:end)*f_draws_emp;  % This uses share'lambda = 1
e_proj = repmat(y_proj,1,n_draws)-f_proj;
e_pct = pctile(e_proj',[0.5 1/6 5/6])';
plot(calvec,y_proj,'LineWidth',2);
hold on;
z = [e_pct(:,2);flipud(e_pct(:,3))];
fill(x2,z,rgb(Cl1),'EdgeColor','none');
plot(calvec,e_pct(:,1),'- r','LineWidth',2);
plot(calvec,y_proj,'- b','LineWidth',2);
hold off;
ylim([-2.5 2.0]);
xlim([1950 2020]);
title('(c) Labor: Sector-specific');
subplot(2,3,4);
plot(calvec,tfp_agg-mean(tfp_agg),'- k','LineWidth',1);
hold on;
plot(calvec,xproj_dm_tfp_agg,'- b','LineWidth',2);
hold off;
title('(d) Aggregate TFP');
ylim([-2.5 2.0]);
xlim([1950 2020]);
% legend('Data (deviation from sample mean)','Low frequency trend','Location','SouthWest');
subplot(2,3,5);
f_proj = WT(:,2:end)*f_draws_tfp;  % This uses share'lambda = 1
f_pct = pctile(f_proj',[0.5 1/6 5/6])';
y_proj = WT(:,2:end)*X_tfp_sec*share_tfp;
plot(calvec,y_proj,'LineWidth',2);
hold on;
z = [f_pct(:,2);flipud(f_pct(:,3))];
fill(x2,z,rgb(Cl1),'EdgeColor','none');
plot(calvec,f_pct(:,1),'- r','LineWidth',2);
plot(calvec,y_proj,'- b','LineWidth',2);
hold off;
ylim([-2.5 2.0]);
xlim([1950 2020]);
title('(e) TFP: Common');  
subplot(2,3,6);
y_proj = WT(:,2:end)*X_tfp_sec*share_tfp;
f_proj = WT(:,2:end)*f_draws_tfp;  % This uses share'lambda = 1
e_proj = repmat(y_proj,1,n_draws)-f_proj;
e_pct = pctile(e_proj',[0.5 1/6 5/6])';
plot(calvec,y_proj,'- k','LineWidth',2);
hold on;
z = [e_pct(:,2);flipud(e_pct(:,3))];
fill(x2,z,rgb(Cl1),'EdgeColor','none');
plot(calvec,e_pct(:,1),'- r','LineWidth',2);
plot(calvec,y_proj,'- b','LineWidth',2);
hold off;
ylim([-2.5 2.0]);
xlim([1950 2020]);
title('(f) TFP: Sector-specific');
orient landscape;
print(fig, [figdir, 'Figure_05_' mlabel], '-dpdf','-bestfit');
close(gcf);

% Plot sector-specific contributions to aggregates by sector
% Decompose aggregates into common unique components
e_draws_emp = NaN(n_y,q,n_draws);
e_draws_tfp = NaN(n_y,q,n_draws);
for i = 1:n_y
    e_draws_emp(i,:,:)=repmat(X_emp_sec(:,i),1,n_draws)-repmat(lam_draws_emp(i,:),q,1).*f_draws_emp;
    e_draws_tfp(i,:,:)=repmat(X_tfp_sec(:,i),1,n_draws)-repmat(lam_draws_tfp(i,:),q,1).*f_draws_tfp;
end
X_agg_emp_f = f_draws_emp.*repmat(lam_draws_emp(i,:),q,1);
X_agg_tfp_f = f_draws_tfp.*repmat(lam_draws_tfp(i,:),q,1);
X_agg_emp_e = NaN(n_y,q,n_draws);
X_agg_tfp_e = NaN(n_y,q,n_draws);
for i = 1:n_y
    X_agg_emp_e(i,:,:) = share_emp(i)*e_draws_emp(i,:,:);
    X_agg_tfp_e(i,:,:) = share_tfp(i)*e_draws_tfp(i,:,:);
end

fig = figure;
for i = 1:n_y
    str = char(sector_names(i));
    e_tmp = squeeze(e_draws_emp(i,:,:));
    e_proj = WT(:,2:end)*e_tmp;
    emp_pct = pctile(e_proj',[0.5 1/6 5/6])';
    subplot(4,4,i);
    plot(calvec,emp_pct(:,1),'- r','LineWidth',1);
    hold on;
    z = [emp_pct(:,2);flipud(emp_pct(:,3))];
    ii = ~isnan(z);
    fill(x2(ii==1),z(ii==1),rgb(Cl1),'EdgeColor','none');
    plot(calvec,emp_pct(:,1),'- r','LineWidth',1);
    plot(calvec,xproj_dm_emp_sec(:,i),'- b','LineWidth',2);
    hold off;
    %ylim([-0.6 0.6]);
    xlim([1950 2020]);
    title(str);
end
orient landscape;
print(fig, [figdir, 'Figure_06_' mlabel], '-dpdf','-bestfit');
close(gcf);

fig = figure;
for i = 1:n_y
    str = char(sector_names(i));
    e_tmp = squeeze(e_draws_tfp(i,:,:));
    e_proj = WT(:,2:end)*e_tmp;
    tfp_pct = pctile(e_proj',[0.5 1/6 5/6])';

    subplot(4,4,i);
    plot(calvec,tfp_pct(:,1),'- r','LineWidth',1);
    hold on;
    z = [tfp_pct(:,2);flipud(tfp_pct(:,3))];
    ii = ~isnan(z);
    fill(x2(ii==1),z(ii==1),rgb(Cl1),'EdgeColor','none');
    plot(calvec,tfp_pct(:,1),'- r','LineWidth',1);
    plot(calvec,xproj_dm_tfp_sec(:,i),'- b','LineWidth',2);
    hold off;
    %ylim([-0.6 0.6]);
    xlim([1950 2020]);
    title(str);
end
orient landscape;
print(fig, [figdir, 'Figure_07_' mlabel], '-dpdf','-bestfit');
close(gcf);

% Compute and plot results Value-added results
% Read in the multipliers from Andrew
filename = 'Long Run Multipliers.xlsx';  
xlsname = ['../data/' filename];
lrm_tfp = xlsread(xlsname,'A1:A16');  
lrm_emp = xlsread(xlsname,'B1:B16');
lrm_tfp_direct = xlsread(xlsname,'C1:C16');  
lrm_emp_direct = xlsread(xlsname,'E1:E16');
% Read in capital contibutions
filename = 'Capital Trends.xlsx';  
xlsname = ['../data/' filename];
cap_tfp = xlsread(xlsname,'A1:P16');
cap_emp = xlsread(xlsname,'Q1:AF16');


% Construct model-based decomposition of GDP
% GDP Data and LR trends
% va_agg = GDP
% xproj_va_agg = lf component
xproj_va_agg_emp = xproj_emp_sec*lrm_emp;
xproj_va_agg_tfp = xproj_tfp_sec*lrm_tfp;
xproj_va_agg_model = xproj_va_agg_emp+xproj_va_agg_tfp;
xproj_va_agg_emp_de = xproj_emp_sec*lrm_emp_direct;
xproj_va_agg_tfp_de = xproj_tfp_sec*lrm_tfp_direct;
xproj_va_agg_model_de = xproj_va_agg_emp_de+xproj_va_agg_tfp_de;
fig = figure;
plot(calvec,va_agg,'- k','LineWidth',1);
hold on;
plot(calvec,xproj_va_agg,'- k','LineWidth',2);
plot(calvec,xproj_va_agg_model,'- b','LineWidth',2);
plot(calvec,xproj_va_agg_model_de,'-- b','LineWidth',2);
xlim([1950 2020]);
legend('Data','Trend (data)','Trend (model, total)','Trend (model, direct effect)','Location','SouthWest');
hold off;
orient landscape;
print(fig, [figdir, 'Figure_09_' mlabel], '-dpdf','-bestfit');
close(gcf);

% Carry out decomposition (demeaned throughout) 
xproj_dm_va_agg_emp = xproj_dm_emp_sec*lrm_emp;
xproj_dm_va_agg_tfp = xproj_dm_tfp_sec*lrm_tfp;
xproj_dm_va_agg_model = xproj_dm_va_agg_emp+xproj_dm_va_agg_tfp;

tmp = lrm_emp'*lam_draws_emp;
tmp = repmat(tmp,q,1).*f_draws_emp;
tmp = WT(:,2:end)*tmp;
xproj_dm_va_agg_emp_f = pctile(tmp',[0.5 1/6 5/6])';

tmp = lrm_tfp'*lam_draws_tfp;
tmp = repmat(tmp,q,1).*f_draws_tfp;
tmp = WT(:,2:end)*tmp;
xproj_dm_va_agg_tfp_f = pctile(tmp',[0.5 1/6 5/6])';

ee_draws_emp = NaN(q,n_draws);
ee_draws_tfp = NaN(q,n_draws);
for iq = 1:q
    tmp = squeeze(e_draws_emp(:,iq,:));
    ee_draws_emp(iq,:)=lrm_emp'*tmp;
    tmp = squeeze(e_draws_tfp(:,iq,:));
    ee_draws_tfp(iq,:)=lrm_tfp'*tmp;
end
tmp = WT(:,2:end)*ee_draws_emp;
xproj_dm_va_agg_emp_u = pctile(tmp',[0.5 1/6 5/6])';
tmp = WT(:,2:end)*ee_draws_tfp;
xproj_dm_va_agg_tfp_u = pctile(tmp',[0.5 1/6 5/6])';

xproj_dm_va_agg_f = xproj_dm_va_agg_emp_f + xproj_dm_va_agg_tfp_f;
xproj_dm_va_agg_u = xproj_dm_va_agg_emp_u + xproj_dm_va_agg_tfp_u;

% Compute posteriors for lambdas for GDP and Compute R-squared for
% common factors
lam_emp_va_draws = (lrm_emp'*lam_draws_emp)';
lam_emp_va = pctile(lam_emp_va_draws,[0.5 1/6 5/6]);
lam_tfp_va_draws = (lrm_tfp'*lam_draws_tfp)';
lam_tfp_va = pctile(lam_tfp_va_draws,[0.5 1/6 5/6]);

% Compute R2 
sigma_f_emp = squeeze(sigma_f_draws(1,1,:));
g_emp_f = g_f_draws(1,:)';
var_emp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.^2);
var_emp_f = (lam_emp_va_draws.^2).*sigma_f_emp.*var_emp_f;
sigma_f_tfp = squeeze(sigma_f_draws(2,2,:));
g_tfp_f = g_f_draws(2,:)';
var_tfp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_tfp_f.^2);
var_tfp_f = (lam_tfp_va_draws.^2).*sigma_f_tfp.*var_tfp_f;
sigma_f_emp_tfp = squeeze(sigma_f_draws(1,2,:));
cov_emp_tfp_f = repmat(sum(diag_SW_I0),n_draws,1)+sum(diag_SW_I1)*(g_emp_f.*g_tfp_f);
cov_emp_tfp_f = (lam_emp_va_draws.*lam_tfp_va_draws).*sigma_f_emp_tfp.*cov_emp_tfp_f;
var_f = var_emp_f + var_tfp_f + 2*cov_emp_tfp_f;

var_emp_u = ((lrm_emp.^2)'*var_emp_u_all)';
var_tfp_u = ((lrm_tfp.^2)'*var_tfp_u_all)';
cov_emp_tfp_u = ((lrm_emp.*lrm_tfp)'*cov_emp_tfp_u_all)';
var_u = var_emp_u + var_tfp_u + 2*cov_emp_tfp_u;

R2 = var_f./(var_f+var_u);
[r2_p_post,r2_x_post] = ksdensity(R2);
% Some Summary Statistics for R2 for paragraph in paper
med_R2 = median(R2);
frac_lt_40_R2 = mean(R2 < 0.40);
[~,ii] = max(r2_p_post);
mode_R2 = r2_x_post(ii);
% -- R2_GDP Results -- %'%
outfile_name    = [outdir, 'R2_GDP_' mlabel '.txt'];
fileID          = fopen(outfile_name,'w');
fprintf(fileID,'Median R2 = %5.2f \n',med_R2);
fprintf(fileID,'Mode R2 = %5.2f \n',mode_R2);
fprintf(fileID,'Prob .lt 0.4 = %5.2f',frac_lt_40_R2);
fclose(fileID);

fig = figure;
subplot(3,3,1);
plot(calvec,xproj_dm_va_agg_model,'- k','LineWidth',2);
hold on;
z = [xproj_dm_va_agg_f(:,2);flipud(xproj_dm_va_agg_f(:,3))];
ii = ~isnan(z);
fill(x2(ii==1),z(ii==1),rgb(Cl1),'EdgeColor','none');
plot(calvec,xproj_dm_va_agg_f(:,1),'- r','LineWidth',2);
plot(calvec,xproj_dm_va_agg_model,'- k','LineWidth',2);
hold off;
xlim([1950 2020]);
title('(a) Common factor');

subplot(3,3,2);
plot(calvec,xproj_dm_va_agg_model,'- b','LineWidth',2);
hold on;
z = [xproj_dm_va_agg_u(:,2);flipud(xproj_dm_va_agg_u(:,3))];
ii = ~isnan(z);
fill(x2(ii==1),z(ii==1),rgb(Cl1),'EdgeColor','none');
plot(calvec,xproj_dm_va_agg_u(:,1),'- r','LineWidth',2);
plot(calvec,xproj_dm_va_agg_model,'- k','LineWidth',2);
hold off;
xlim([1950 2020]);
title('(b) Sector specific');

subplot(3,3,3);
plot(r2_x_post,r2_p_post,'LineWidth',3);
xlim([0 1]);

orient landscape;
print(fig, [figdir, 'Figure_10_' mlabel], '-dpdf','-bestfit');
close(gcf);


% Plot Sector-specific contributions by sector
X_va_agg_emp_e = NaN(n_y,q,n_draws);
X_va_agg_tfp_e = NaN(n_y,q,n_draws);
for i = 1:n_y
    X_va_agg_emp_e(i,:,:) = lrm_emp(i)*e_draws_emp(i,:,:);
    X_va_agg_tfp_e(i,:,:) = lrm_tfp(i)*e_draws_tfp(i,:,:);
end
X_va_agg_e = X_va_agg_emp_e + X_va_agg_tfp_e;

fig = figure;
for i = 1:n_y
    str = char(sector_names(i));
    e_tmp = squeeze(X_va_agg_e(i,:,:));
    e_proj = WT(:,2:end)*e_tmp;
    e_pct = pctile(e_proj',[0.5 1/6 5/6])';


    subplot(4,4,i);
    plot(calvec,e_pct(:,1),'- r','LineWidth',1)
    hold on;
    z = [e_pct(:,2);flipud(e_pct(:,3))];
    ii = ~isnan(z);
    fill(x2(ii==1),z(ii==1),rgb(Cl1),'EdgeColor','none');
    plot(calvec,e_pct(:,1),'- r','LineWidth',1);
    %         plot(calvec,xproj_dm_va_agg_model,'- k','LineWidth',2);
    hold off;
    xlim([1950 2020]);
    title(str);
end
orient landscape;
print(fig, [figdir, 'Figure_12_' mlabel], '-dpdf','-bestfit');
close(gcf);

% Plot Sector-specific capital trends
xproj_cap_emp = xproj_emp_sec*cap_emp';
xproj_cap_tfp = xproj_tfp_sec*cap_tfp';
xproj_cap_model = xproj_cap_emp+xproj_cap_tfp;

fig = figure;
for i = 1:n_y
    str = char(sector_names(i));

    x1 = xproj_cap_model(:,i)-mean(xproj_cap_model(:,i))+mean(xproj_cap_sec(:,i));
    x2 = xproj_cap_sec(:,i);
    subplot(4,4,i);
    hold on;
    plot(calvec,x1,'- r','LineWidth',1);
    plot(calvec,x2,'- k','LineWidth',2);
    hold off;
    xlim([1950 2020]);
    title(str);
    ylim([5*floor(min([x1;x2]-2)/5) 5*ceil(max([x1;x2]+2)/5)])
end
orient landscape;
legend('Model','Data')
print(fig, [figdir, 'Figure_A3_' mlabel], '-dpdf','-bestfit');
close(gcf);




