    % model_multipliers.m
% compute long run multipliers
% 
% Revised: 2020-04-26
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % 

%% -- SETUP -- %%
% -- Clear Workspace -- %
clear;
clc;
close all;
tic; 


%% -- IMPORT DATA - %%
load('../data/KLEMSbea16_1947_1963_1987_2018.mat');
load('../data/data_io_cap/IO_2015');             % loading parameters from the Make and Use Tables: theta, phi
load('../data/data_io_cap/capflow');             % loading parameters from the capital flow tables   

N       = 16;
years   = 1950:2018;
nyears  = length(years);

%  value-added shares
vshares     = v./sum(v,2);
mvashares   = mean(v(4:end,:)./sum(v(4:end,:),2))';

% mean labor shares
empshares   = n./sum(n,2); 
mempshares  = mean(n(4:end,:)./sum(n(4:end,:),2))';

% approximating the zeros in theta
thetanew = theta + (theta==0)*0.0001;
errtheta = sum(thetanew) - 1;
thetanew = thetanew - errtheta./size(thetanew,1);
theta = thetanew;

% Adjust omega for repair and maintenance expenses, McGrattan and Schmitz(1999)
rm = 0.0;
omeganew = omega + rm*eye(size(omega,1));
omeganew = omeganew./(1+rm);
omega = omeganew;
bta = 0.96;             % discount rate
% delta_d = diag(depreciations);            % depreciation rate
gma_d = diag(gma);
alpha_d = diag(alpha);
Xi = ((inv(eye(N) - gma_d*alpha_d*omega' - (eye(N)-gma_d)*phi'))*gma_d)';

% Multiplier
mult_tfp        = (mvashares'*(eye(N)+alpha_d*omega'*Xi'))';
mult_emp        = (eye(N)-alpha_d)*(mvashares'*(eye(N)+alpha_d*omega'*Xi'))';
mult_tfp_dir    = (mvashares'*(eye(N)))';
mult_tfp_ind 	= (mvashares'*(alpha_d*omega'*Xi'))';
mult_emp_dir    = (eye(N)-alpha_d)*(mvashares'*(eye(N)))';
mult_emp_ind 	= (eye(N)-alpha_d)*(mvashares'*(alpha_d*omega'*Xi'))';

mult = [mult_tfp mult_emp mult_tfp_dir mult_tfp_ind mult_emp_dir mult_emp_ind];

xlswrite('Long Run Multipliers.xlsx',mult);


% capital 
cap_tfp         = omega'*Xi';
cap_emp         = omega'*Xi'*(eye(N)-alpha_d);
xlswrite('Capital Trends.xlsx',[cap_tfp cap_emp])


% sectoral producer price multiplier (gross output prices)
rdum=( kron(ones(N,1),theta') - eye(N) )*Xi';
price_tfp =rdum;
price_emp =rdum*(eye(N)-alpha_d);
xlswrite('Price Trends.xlsx',[price_tfp price_emp])

%% -- END -- %%
toc;